
/****************************************************************************
** Form implementation generated from reading ui file './rooms.ui'
**
** Created: Sat Jan 13 16:10:02 2007
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "rooms.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qframe.h>
#include <qcombobox.h>
#include <qlineedit.h>
#include <qradiobutton.h>
#include <qtextedit.h>
#include <qheader.h>
#include <qlistview.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

static const char* const img0_rooms[] = { 
"11 18 53 1",
"g c #0075e6",
"b c #0075ee",
"R c #0079e6",
"Y c #0079ee",
". c #0879ee",
"t c #1881ee",
"x c #2989ee",
"S c #298dee",
"X c #3191ee",
"U c #3991ee",
"L c #5aa5f6",
"C c #62aaf6",
"# c #73aae6",
"d c #73aee6",
"a c #73aeee",
"e c #7baee6",
"c c #7bb2ee",
"O c #7bb6ff",
"f c #83b6ee",
"P c #83baff",
"h c #8bbaee",
"i c #8bbeee",
"Q c #8bbeff",
"l c #94beee",
"j c #94c2ee",
"N c #94c6ff",
"k c #9cc2f6",
"n c #9cc6ee",
"m c #a4c6f6",
"q c #a4caf6",
"G c #a4cef6",
"p c #accaf6",
"o c #accef6",
"W c #acd2f6",
"M c #acd2ff",
"s c #b4d2f6",
"V c #b4d6ff",
"r c #bddaf6",
"y c #bddaff",
"w c #c5daf6",
"v c #c5deff",
"u c #cde2ff",
"z c #d5e6f6",
"B c #d5e6ff",
"A c #deeaff",
"T c #deeeff",
"H c #e6f2ff",
"E c #eef2ff",
"F c #eef6ff",
"D c #f6f6ff",
"J c #f6faff",
"K c #fffaff",
"I c #ffffff",
".#a#a#a#a#a",
"bcdcecdcdcd",
".ffffffffff",
"ghhhhhhihhh",
".jklkjkjkjk",
"bmnmnmnmnmn",
".oopopoooqo",
"grsssssssss",
"tuvwvwvwvwv",
"xyzABAzABAz",
"CCDEFEDEFEF",
"G.HIJIJIJIK",
"IxLIIIIIIII",
"IMgNIIIIIII",
"IIO.PIIIIII",
"IIIQRSuIJJF",
"IIIITU.LVBI",
"IIIIIIWLXYg"};

static const char* const img1_rooms[] = { 
"21 18 33 1",
"E c #0075e6",
"C c #0075ee",
"D c #0079ee",
"# c #73aae6",
"c c #73aee6",
". c #73aeee",
"a c #7baee6",
"b c #7bb2ee",
"d c #83b6ee",
"e c #8bbaee",
"f c #8bbeee",
"j c #94beee",
"h c #94c2ee",
"i c #94c2f6",
"g c #9cc2f6",
"k c #9cc6ee",
"m c #9cc6f6",
"l c #a4c6f6",
"o c #accaf6",
"n c #accef6",
"q c #acd2f6",
"p c #b4d2f6",
"s c #c5daf6",
"r c #c5deff",
"v c #d5e6f6",
"t c #d5e6ff",
"u c #deeaff",
"x c #eef2ff",
"w c #eef6ff",
"y c #f6f6ff",
"z c #f6faff",
"B c #fffaff",
"A c #ffffff",
".#.#.#.#.#.#.#.#.#.#.",
"abcbcbcbabcbabcbcbcbc",
"ddddddddddddddddddddd",
"eeeeeeefefeeeeeeeeeee",
"ghghghghghijghghgjghg",
"klklklklklklklkmklkmk",
"nonnnnnonnnonnnnnnnon",
"ppppppppppppqpppppppp",
"rsrsrsrsrsrsrsrsrsrsr",
"tuvutuvutuvutututuvut",
"wxyxwxwxwxyxwxwxwxwxw",
"zABAzBzAzAzAzBzAzAzAz",
"AAAAAAAAAAAAAAAAAAAAA",
"AAAAAAAAAAAAAAAAAAAAA",
"AAAAAAABABAAAAABAAAAA",
"wywywywywywywywywywyw",
"AAAAAAAAAAAAAAAAAAAAA",
"CDEDCDEDCDEDCDEDCDEDC"};

static const char* const img2_rooms[] = { 
"11 18 51 1",
"d c #0075e6",
"g c #0075ee",
"M c #0079ee",
"a c #0879ee",
"T c #087dee",
"u c #107dee",
"K c #2085ee",
"z c #2089ee",
"R c #3191ee",
"V c #52a1f6",
"E c #5aa5f6",
"J c #62aaf6",
"D c #62aef6",
"# c #73aae6",
"b c #73aee6",
". c #73aeee",
"P c #73b6f6",
"c c #7bb2ee",
"e c #83b6ee",
"O c #83beff",
"f c #8bbaee",
"j c #94beee",
"i c #94c2ee",
"L c #94c6ff",
"h c #9cc2f6",
"k c #9cc6ee",
"m c #9cc6f6",
"l c #a4c6f6",
"I c #a4caf6",
"N c #a4ceff",
"o c #accaf6",
"n c #accef6",
"W c #acceff",
"p c #b4d2f6",
"S c #b4d6ff",
"q c #bddaf6",
"y c #bddaff",
"s c #c5daf6",
"r c #c5deff",
"t c #cde2ff",
"Q c #cde6ff",
"x c #d5e6f6",
"v c #d5e6ff",
"U c #d5eaff",
"w c #deeaff",
"B c #eef2ff",
"A c #eef6ff",
"C c #f6f6ff",
"F c #f6faff",
"H c #fffaff",
"G c #ffffff",
".#.#.#.#.#a",
"bcbcbcbcbcd",
"eeeeeeeeeea",
"ffffffffffg",
"hihihjhihja",
"klklklkmkld",
"nnnnnononna",
"pppppppppqg",
"rsrsrsrsrtu",
"vwvwvwxwvyz",
"ABABABABCDE",
"FGFHFGFGBuI",
"GGGGGGGGJKG",
"GGGGGGGLMNG",
"GGGGGGOaPGG",
"AFFGQRMOHGG",
"GvSETRUGGGG",
"gMRVWGGGGGG"};

static const char* const img3_rooms[] = { 
"34 31 4 1",
"a c #004894",
"b c #004c94",
"# c #004c9c",
". c #ffffff",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba"};

static const char* const img4_rooms[] = { 
"51 16 89 2",
".R c #000000",
"#w c #000400",
"#. c #000810",
".o c #000c10",
".M c #000c18",
".n c #001020",
".m c #001429",
".l c #001831",
".p c #001c39",
".k c #002041",
".j c #00244a",
".g c #002c5a",
".i c #003062",
".f c #00346a",
".e c #00386a",
".d c #003873",
".9 c #003c73",
".c c #003c7b",
".h c #004083",
".b c #00448b",
".# c #004894",
".a c #004c94",
"Qt c #004c9c",
".5 c #080808",
".0 c #080c10",
".V c #080c18",
".G c #081018",
"#t c #101010",
"#l c #101410",
".z c #101820",
"#n c #181418",
"#h c #181818",
".U c #181c18",
".q c #182431",
".Z c #201c20",
"#c c #202020",
"#v c #202420",
".8 c #292429",
".3 c #312c31",
".L c #313031",
"#u c #313431",
".Y c #393839",
".4 c #393c39",
"#k c #413c41",
".N c #414041",
".F c #4a444a",
"#g c #4a484a",
"#b c #4a4c4a",
".T c #524c52",
".7 c #5a595a",
"#s c #625d62",
".r c #626162",
".2 c #626562",
".A c #62656a",
".K c #6a656a",
".y c #6a696a",
".W c #6a6d73",
".X c #7b757b",
"#i c #7b797b",
"#f c #837d83",
".E c #838183",
".S c #838583",
"#a c #8b858b",
".s c #8b898b",
"#r c #8b8d8b",
".6 c #948d94",
"#d c #949194",
".x c #9c999c",
"#p c #9c9d9c",
".J c #a49da4",
".t c #a4a1a4",
".B c #aca5ac",
"## c #acaaac",
".D c #acaeac",
"#o c #b4aeb4",
".O c #b4b2b4",
".1 c #b4b6b4",
"#e c #bdb6bd",
".I c #bdbabd",
".H c #bdbebd",
".w c #c5bec5",
".P c #c5c2c5",
".Q c #c5c6c5",
".C c #cdc6cd",
".u c #cdcacd",
".v c #d5ced5",
"#j c #d5d2d5",
"#m c #eee6ee",
"#q c #eeeaee",
"Qt.#.a.#Qt.#.a.#Qt.#.a.#.#.b.b.c.c.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.f.g",
".#.#.#.#.#.#.#.#.#.#.b.h.d.i.j.k.l.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.n.o",
".a.#Qt.#.a.#Qt.#.#.c.f.j.p.n.q.r.s.t.u.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.w.x.y",
".#.#.#.#.#.#.b.h.i.j.n.z.A.B.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.C.D.E.F",
"Qt.#.a.#.#.b.c.j.m.G.A.H.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.I.J.K.L",
".#.#.#.#.h.f.p.M.N.O.P.Q.P.C.P.Q.R.R.R.R.R.C.P.Q.P.C.P.Q.P.C.P.Q.P.C.R.R.P.C.P.Q.P.C.P.Q.P.C.P.O.S.T.U",
".a.#.#.h.g.m.V.W.P.P.P.P.P.P.P.P.R.R.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.w.t.X.Y.Z",
".#.#.h.g.n.0.S.P.H.P.H.P.H.P.H.P.R.R.H.P.H.P.H.P.R.R.R.P.H.R.R.R.H.P.R.R.H.P.H.P.H.P.H.P.H.P.1.x.2.3.4",
"Qt.b.f.m.5.E.w.H.w.H.w.H.w.H.w.H.R.R.R.R.R.H.w.R.R.H.w.H.R.R.w.H.w.H.R.R.w.H.w.H.w.H.w.H.w.H.O.6.7.8.y",
".b.9.p#..y.I.I.I.I.I.I.I.I.I.I.I.R.R.I.I.I.I.I.I.R.R.I.I.R.R.I.I.I.I.R.R.I.I.I.I.I.I.I.I.I.I###a#b#c#d",
".h.j.n.N.I#e.I#e.I#e.I#e.I#e.I#e.R.R.I#e.I#e.I#e.I.R.R#e.R.R.I#e.I#e.R.R.I#e.I#e.I#e.I#e.I#e.B#f#g#h.I",
".i.m.0##.O.1.O#e.O.1.O#e.O.1.O#e.R.R.R.R.R.1.O.R.R.R.O#e.O.R.R.R.O.1.R.R.O.1.O#e.O.1.O#e.O.1.t#i.4#h#j",
".j#..y.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.t#i#k#l#m",
".n#n##.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O#p.X.Y#n#q",
".L#b.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.E#s.L#t.P",
"#u#v.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z#h#n.5#w.2"};

static const char* const img5_rooms[] = { 
"28 31 202 2",
"ao c #000008",
"#k c #000810",
"#d c #000c18",
"af c #001018",
"#j c #001020",
"#c c #001429",
"#S c #001831",
"#5 c #001c39",
"#i c #002041",
"#b c #00244a",
"#I c #002852",
"#h c #002c5a",
"#a c #003062",
"#4 c #003462",
"#y c #00346a",
"#H c #003873",
"#g c #003c7b",
"## c #004083",
"#x c #004483",
"#. c #00448b",
"#p c #00488b",
".9 c #004894",
"#o c #004c94",
".8 c #004c9c",
"#q c #080810",
"aE c #101820",
"aw c #102439",
"#6 c #182020",
".N c #202020",
".H c #202420",
"ax c #202429",
".G c #292829",
".7 c #292c29",
".V c #312c31",
".F c #313031",
".2 c #313431",
".E c #393439",
".1 c #393839",
".M c #393c39",
"#T c #393c41",
".D c #414041",
".O c #414441",
"#l c #41444a",
"aj c #4195ee",
".C c #4a444a",
".W c #4a4c4a",
"aB c #4a99ee",
"ap c #525052",
".6 c #525552",
"#J c #52555a",
"#8 c #52a1ee",
".B c #5a555a",
".0 c #5a595a",
".L c #5a5d5a",
".w c #626162",
".v c #626562",
"a7 c #62797b",
"bh c #6a656a",
".x c #6a696a",
".u c #6a6d6a",
"#F c #6a9dc5",
"al c #6aaeee",
".t c #737173",
"bc c #738d94",
"a4 c #73aed5",
"a# c #73b2f6",
".K c #7b797b",
".3 c #7b7d7b",
".Z c #7b7d83",
"b# c #7b999c",
"#B c #7ba1c5",
"aG c #7baad5",
"aQ c #7bb2d5",
"a. c #7bb6ee",
".s c #837d83",
".5 c #838183",
".r c #83858b",
"bf c #839594",
"#7 c #83a5cd",
"#E c #83aad5",
"#L c #83b2d5",
"#U c #83b6cd",
"#Y c #83bef6",
".A c #8b858b",
".P c #8b898b",
"ag c #8b8d8b",
"a1 c #8baab4",
"#Q c #8bb6de",
"ar c #8bbad5",
"ay c #8bbed5",
"#2 c #8bbede",
"ad c #8bc2d5",
"#X c #8bc2f6",
"an c #8bc6de",
"aZ c #8bc6e6",
"a6 c #949194",
".q c #94959c",
"#D c #94b6d5",
"bd c #94bec5",
"#u c #94bed5",
"az c #94bee6",
"#A c #94c2d5",
"aS c #94c2de",
"#R c #94c6de",
"aX c #94cae6",
"aY c #94cee6",
".4 c #9c959c",
".J c #9c9da4",
"b. c #9caaac",
"#C c #9cb6d5",
"#G c #9cc6de",
"aT c #9cc6e6",
"a2 c #9ccacd",
"#v c #9ccade",
"aL c #9cceee",
"aD c #9cd2e6",
"aK c #9cd6e6",
"#e c #a49da4",
".p c #a4a1a4",
"ah c #a4bede",
"as c #a4cae6",
"#9 c #a4caf6",
".Y c #acaaac",
"a8 c #accecd",
"aW c #acdae6",
".j c #b4b2b4",
".Q c #b4b6b4",
".k c #b4b6bd",
"#3 c #b4dae6",
"a0 c #b4daee",
"aU c #b4deff",
".i c #bdb6bd",
".h c #bdbabd",
".I c #bdbebd",
"be c #bddede",
"a9 c #bddee6",
"aF c #bddeee",
"aJ c #bddef6",
"ac c #bde6ff",
"#m c #c5bec5",
".g c #c5c2c5",
".f c #c5c6c5",
"#V c #c5cee6",
"#M c #c5d2e6",
"bg c #c5dede",
"aO c #c5def6",
"#t c #c5e2ee",
"aR c #c5e6e6",
"bb c #c5e6ee",
"a3 c #c5eaee",
"a5 c #c5eaff",
"#P c #c5eeff",
".R c #cdc6cd",
".o c #cdcacd",
".S c #cdcecd",
"#w c #cde6ee",
"#K c #cdeaee",
"am c #cdeeff",
"#1 c #cdf6ff",
".e c #d5ced5",
"#r c #d5d2d5",
".d c #d5d6d5",
"ak c #d5e6f6",
"#z c #d5eaee",
"ai c #d5eaff",
"aP c #d5eef6",
"aC c #d5eeff",
"aM c #d5faff",
".z c #dedade",
".U c #dedede",
".n c #dedee6",
"#s c #deeaee",
"av c #deeeee",
"#0 c #def6f6",
"#O c #defaff",
".c c #e6dee6",
"aq c #e6e2e6",
"#f c #e6e6e6",
"#n c #e6eaee",
"ba c #e6eeee",
"ae c #e6eef6",
"#Z c #e6f2f6",
"au c #e6f6ff",
"aH c #e6faf6",
"ab c #e6faff",
".X c #eee6ee",
".b c #eeeaee",
".m c #eeeeee",
"aV c #eeeef6",
"#W c #eef2ff",
"aI c #eef6ff",
"aN c #eefaff",
"at c #eeffff",
".y c #f6eef6",
".T c #f6f2f6",
".a c #f6f6ff",
"aA c #f6faf6",
"#N c #f6ffff",
".l c #fff6ff",
".# c #fffaff",
"aa c #fffff6",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.g.h.i.j.i.k",
"QtQtQtQtQtQtQtQtQtQtQtQt.#.l.m.n.o.i.p.q.r.s.t.u.v.v.w.x",
"QtQtQtQtQtQtQtQtQtQtQt.l.y.z.g.p.A.x.B.C.D.E.F.G.G.H.G.G",
"QtQtQtQtQtQtQtQtQt.#.b.z.I.J.K.L.M.G.N.G.O.u.P.p.Q.R.S.o",
"QtQtQtQtQtQtQt.#.T.U.f.J.s.B.M.N.V.W.P.h.X.b.m.b.y.b.m.b",
"QtQtQtQtQtQt.a.b.S.Y.Z.0.1.N.2.3.h.b.b.b.b.b.b.b.b.b.b.b",
"QtQtQtQtQt.l.X.g.4.v.D.N.E.5.e.b.m.b.y.b.m.b.y.b.m.b.y.b",
"QtQtQtQt.T.c.i.P.6.7.N.x.f.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b",
".8.9.9#.###a#b#c#d.G#e#f.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b",
".9.9#.#g#h#i#j#k#l#m.b.b.b.b#n#n#n#n#n.b.b.b.b.b.b.b.b.b",
"#o#p###a#i#j#q.0#r.b.y.b.m#s#t#u#u#v#w#n.m.b.y.b.m.b.y.b",
"#.#x#y#b#j#k.L.z.b.b.b.b#z#A#B#C#D#E#F#G#z.b.b.b.b.b.b.b",
"#.#H#I#c#k#J.U.b.y.b.m#K#L#MQtQt#N#O#P#Q#R#s.m.b.y.b.m.b",
"#H#h#S#d#T.e.b.b.b.b#s#U#V#W#X#Y#ZQt#0#1#2#3#n.b.b.b.b.b",
"#4#5#j#6.i.b.y.b.m#n#t#7Qt#8#9a.a#aaQtabacadae.b.m.b.y.b",
"#5af#qag.b.b.b.b.b#n#AahaiajaaakalQtaa#Naman#z.b.b.b.b.b",
"#kaoapaq.y.b.m.b.y#narasata.Qtaka#aaQt#Nau#Rav.b.y.b.m.b",
"awax.Q.b.b.b.b.b.b#nayaz#OQtaaaAaB#WaaQtaCaD#s.b.b.b.b.b",
"aE.x.b.b.m.b.y.b.m#naFaG#1aHQtaaak#8aIQtaJaKae.b.m.b.y.b",
"ax#m.b.b.b.b.b.b.b.b#sayaLaMaNQtaaaOaaQtaPaQaR.b.b.b.b.b",
".waq.m.b.y.b.m.b.y.b.m#zaSaTamab#NaNQtaaabaUay#zaV.b.m.b",
".p.b.b.b.b.b.b.b.b.b.b.b#zaWanaXaYaZa0#OaN#Na1a2#s.b.b.b",
"#r.b.y.b.m.b.y.b.m.b.y.b.m#nae#zava3a4a5Qtaqa6a7a8#n.y.b",
"#f.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#na9aQb..g.o.5b##s.b.b",
".y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.bbabbbc.5.R.pbd#s.m.b",
".b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#nbeb#bfbgaR#n.b.b",
".m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.bba#z#w#zba.b.y.b",
".b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b",
".y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b",
".I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m",
".xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh"};

static const char* const img6_rooms[] = { 
"28 18 47 1",
"c c #5a9de6",
"b c #5aa1e6",
"a c #62a1e6",
"d c #62a5e6",
"h c #6aa5e6",
"f c #6aaae6",
"g c #6aaaee",
"# c #737173",
"i c #73aae6",
"e c #73aaee",
"k c #73aee6",
"j c #73aeee",
"n c #7bb2e6",
"l c #7bb2ee",
"m c #83b2ee",
"o c #83b6e6",
"q c #83b6ee",
"p c #83baee",
"r c #8bb6ee",
"s c #8bbaee",
"u c #8bbeee",
"v c #94beee",
"t c #94bef6",
"y c #94c2ee",
"w c #9cc2ee",
"x c #9cc2f6",
"z c #9cc6ee",
"A c #9cc6f6",
"C c #a4caee",
"B c #a4caf6",
"D c #accaf6",
"E c #acceee",
"G c #accef6",
"F c #b4d2f6",
"I c #bdd6f6",
"J c #bddaf6",
"H c #bddaff",
"K c #cde2f6",
"M c #cde2ff",
". c #d5d2d5",
"L c #d5e2ff",
"O c #deeeff",
"N c #e6eeff",
"P c #eef6ff",
"Q c #f6f6ff",
"S c #fffaff",
"R c #ffffff",
"............................",
"############################",
"ababababacababacacacababacab",
"adadadadadadadadadadadadadad",
"efghghghghghehgfghgfghghghgh",
"ijijijikijijijijijijijijijij",
"llmllnmllnmllnmllnmlllmllnml",
"opqpqpqroqqsqpqropqqqqqrqpqp",
"tuvutuvutuvutuvutvvutvvutuvu",
"wxyzwAyzyxyzwxyzyxywwAyzwAyz",
"BCDBBCDBBCDBBCDBBCDBBCDBDCDB",
"EFGFEFGFEFGFGFGFEFGFGFGFEFGF",
"HIJIHIHIHIHIHIHIHIJIHIHIHIJI",
"KLKLKLKMKLKMKLKLKLKMKLKLKLKL",
"NNNNNNNNNNNNNONNNNNNNNNNNNNN",
"PQPQPQPQPQPQPQPQPQPQPQPQPQPQ",
"RRRRRRRRRRRRRSRRRSRSRRRRRRRR",
"RRRRRRRRRRRRRRRRRRRRRRRRRRRR"};

static const char* const img7_rooms[] = { 
"311 12 33 1",
"k c #0075e6",
"c c #0075ee",
"E c #0079ee",
". c #0879ee",
"q c #1881ee",
"o c #3995f6",
"r c #4a9df6",
"i c #73aee6",
"j c #7bb2ee",
"g c #83b6e6",
"l c #83b6ee",
"n c #83bae6",
"f c #83baee",
"m c #8bbae6",
"h c #8bbaee",
"e c #8bbeee",
"d c #94beee",
"D c #9ccaff",
"B c #a4caee",
"C c #a4caf6",
"A c #accef6",
"p c #acd2ff",
"z c #b4d2f6",
"s c #b4d6f6",
"u c #bdd6f6",
"t c #bdd6ff",
"w c #bddaf6",
"v c #c5daff",
"b c #c5deff",
"y c #cddeff",
"x c #cde2ff",
"a c #cde6ff",
"# c #d5e6ff",
".##a#bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb",
"cdefghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghg",
".ijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijij",
"klglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglg",
".lfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlf",
"clglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglg",
".fhhhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhhhfhfhlhlhlhfhfhfhfhfhfhfhfhfhfhfhlhlhlhfhfhfhfhlhlhlhfhhhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhlhlhlhfhfhfhfhfhfhfhfhfhfhfhfhfhlhlhlhlhlhfhfhfhhhfhhhfhfhfh",
"khmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhhhnhhhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhhhnhhhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhm",
".hdedededededededededededededededededededededededededededededededededededededededhehdhehdhdhdhdedededededededededededededededededededededhdhdhdededededededededededededededededededededededededededededededededhdhdhdhdededededededededededededededededededededededededededededededededededededededededededhdhdhdhdeded",
"coddddedededddedddedddedddedddedededededededededddedddedddddddddddedededededddedddedddedddedddedddedddedededededededededededddedddedddedddedddedddedddedddedddedededededededededddedddedddedededddedddedededededededededddedddedededededededddedddedddedddedddedededededededddedededededddedddedddededededddddddddedede",
"pqrststststststststststststststststststststststststuvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwbbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxx#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#bxbxbxbxbxbxbxbxbxbxbxbyvvwvwvwvwvwvwvwvwvwvwvwvuuststststststststststststststststststststststststststszAABC",
"aDcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEc"};

static const unsigned char img8_rooms[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x2d, 0x00, 0x00, 0x00, 0x1f,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x73, 0xa8, 0x44, 0x3c, 0x00, 0x00, 0x03,
    0x15, 0x49, 0x44, 0x41, 0x54, 0x58, 0x85, 0xd5, 0x96, 0xdd, 0x6b, 0x14,
    0x57, 0x14, 0xc0, 0x7f, 0xe7, 0xde, 0x3b, 0x3b, 0x33, 0xab, 0x59, 0x92,
    0x35, 0x71, 0xa3, 0x11, 0x59, 0x69, 0x36, 0x1f, 0x86, 0x4d, 0x52, 0xbf,
    0x6a, 0xd9, 0x18, 0xc5, 0xa8, 0xad, 0x0a, 0x4d, 0x8b, 0xa4, 0x01, 0x45,
    0x2c, 0x0a, 0x42, 0x4b, 0xab, 0xb4, 0xc4, 0xd4, 0x37, 0x1f, 0xfa, 0xcf,
    0xf4, 0xc5, 0xbf, 0xa1, 0x2f, 0xbe, 0xf7, 0x5b, 0xc5, 0x08, 0x8a, 0x3e,
    0xe8, 0x83, 0xca, 0x8a, 0xb0, 0x9a, 0x1a, 0x9d, 0x3e, 0x24, 0xd7, 0xc6,
    0x90, 0x99, 0xd9, 0xdc, 0xac, 0x6e, 0xfa, 0x83, 0x79, 0x19, 0xe6, 0x9c,
    0xfb, 0x9b, 0x73, 0xcf, 0x9c, 0x3b, 0xf2, 0xcb, 0x4c, 0x2d, 0xe2, 0x7f,
    0x86, 0xb9, 0x36, 0x53, 0x6d, 0xb6, 0xc3, 0x8a, 0x31, 0xd5, 0xe7, 0xaf,
    0x9a, 0xed, 0xb0, 0x62, 0x4c, 0x8b, 0xaf, 0x9c, 0x02, 0x45, 0xdc, 0x17,
    0x8d, 0x52, 0x1a, 0x32, 0x2e, 0xb7, 0x8d, 0x33, 0xab, 0x59, 0xdc, 0x15,
    0xd7, 0x35, 0x6d, 0x9c, 0x5b, 0x99, 0x9b, 0x8c, 0xd1, 0xaa, 0x09, 0xa5,
    0x76, 0xc5, 0xb6, 0x87, 0x76, 0x75, 0xae, 0x23, 0x2e, 0xae, 0x77, 0x9d,
    0xcb, 0xb4, 0x10, 0x68, 0x9c, 0xad, 0xd3, 0xa6, 0xbb, 0xc4, 0xcb, 0xd5,
    0x73, 0x30, 0x24, 0xc5, 0xbe, 0x69, 0x8f, 0x95, 0x2e, 0x90, 0xf4, 0xaa,
    0xf5, 0x96, 0xc1, 0xf5, 0x54, 0x33, 0x9e, 0x96, 0x3b, 0x4f, 0x5f, 0x90,
    0xf5, 0x14, 0x9e, 0xa7, 0x09, 0x8c, 0x22, 0xa3, 0x04, 0xe3, 0x98, 0xaf,
    0x21, 0xa4, 0x6e, 0xa2, 0x9a, 0x7e, 0x10, 0x01, 0x18, 0xc5, 0x5d, 0x25,
    0xcc, 0x86, 0x1e, 0xcf, 0xf6, 0x74, 0x49, 0xed, 0xc0, 0x36, 0xd5, 0xdb,
    0x1a, 0x50, 0x88, 0xcf, 0x9c, 0x5e, 0xa7, 0xd8, 0x5d, 0x72, 0x9e, 0xb3,
    0xf3, 0x19, 0x25, 0x8a, 0x22, 0xf4, 0x8f, 0x0f, 0x4b, 0xc0, 0x3a, 0x60,
    0x13, 0xf0, 0x19, 0x30, 0x2e, 0x82, 0x29, 0xb6, 0xca, 0x8d, 0x4f, 0x4a,
    0xaa, 0x65, 0xb0, 0x20, 0xdb, 0x8d, 0xc2, 0x5f, 0x9a, 0xc0, 0x75, 0x7b,
    0x25, 0x4a, 0x93, 0x5e, 0x3e, 0xb7, 0x8d, 0x12, 0x35, 0xfd, 0x60, 0xb9,
    0xa8, 0x02, 0xf0, 0x05, 0x30, 0x01, 0x54, 0x42, 0x8f, 0xdb, 0x07, 0x8a,
    0xea, 0xf1, 0xe1, 0x6e, 0xd5, 0x9b, 0x0f, 0xa5, 0x00, 0xc9, 0x85, 0x8e,
    0x48, 0xe9, 0x79, 0x79, 0x5b, 0x62, 0xb9, 0xf8, 0x24, 0xe2, 0xa4, 0x2d,
    0x1e, 0xb0, 0x03, 0x38, 0x03, 0x8c, 0x6b, 0x81, 0x9e, 0x76, 0x35, 0x73,
    0x62, 0x40, 0x77, 0xf4, 0x75, 0xc8, 0xf6, 0xd8, 0xa4, 0x09, 0x42, 0x00,
    0x51, 0x8a, 0x74, 0x1a, 0x69, 0xd2, 0x8b, 0xd9, 0xca, 0x7c, 0xf5, 0x4f,
    0x01, 0xe5, 0xb6, 0x50, 0xfe, 0xfe, 0xbc, 0x5f, 0xff, 0xb3, 0xaf, 0xa8,
    0xfa, 0x5a, 0x7c, 0x69, 0x73, 0x5c, 0xdf, 0x89, 0x95, 0x48, 0x5b, 0x02,
    0x60, 0x3f, 0x70, 0x16, 0x38, 0x94, 0xd1, 0x54, 0x47, 0x8b, 0xfa, 0xfe,
    0x99, 0x1d, 0xa6, 0x9c, 0xf3, 0x25, 0xdf, 0x70, 0xc3, 0x45, 0xd8, 0xb6,
    0x71, 0x91, 0xb6, 0x68, 0xa0, 0x07, 0xf8, 0x0a, 0x38, 0x17, 0x18, 0x1e,
    0x9d, 0x1c, 0xf2, 0x1e, 0x8d, 0xf7, 0x9b, 0x9d, 0x19, 0x4d, 0xb0, 0xba,
    0xdf, 0xc0, 0xb8, 0xdb, 0x0b, 0xd3, 0x63, 0x15, 0xd2, 0x8b, 0x19, 0x06,
    0xa6, 0x80, 0x13, 0x1b, 0xb2, 0xf2, 0xd7, 0xb7, 0x7b, 0x33, 0xba, 0x52,
    0xd4, 0xc3, 0x09, 0x87, 0xe2, 0xaa, 0x68, 0x94, 0x34, 0x40, 0x06, 0x18,
    0x03, 0xa6, 0x04, 0x3e, 0x2a, 0xb5, 0xab, 0x5f, 0x2f, 0x8d, 0x06, 0x9d,
    0xbd, 0xed, 0xaa, 0x7b, 0xe9, 0x83, 0xd1, 0xc2, 0xe8, 0x89, 0x3f, 0x6d,
    0x63, 0xde, 0xd5, 0x7e, 0xc0, 0x0d, 0x94, 0xb6, 0xac, 0x07, 0xbe, 0x04,
    0xbe, 0x57, 0xc2, 0xc6, 0xb1, 0x0f, 0xcc, 0xf5, 0x0b, 0x15, 0x7f, 0xa0,
    0x3d, 0x2b, 0x1d, 0xf6, 0x81, 0x28, 0x65, 0x4e, 0xa7, 0x75, 0xd6, 0xbb,
    0x90, 0xb6, 0x74, 0x02, 0xdf, 0x00, 0xe7, 0x43, 0x4f, 0xaa, 0x5f, 0xef,
    0xf5, 0x9f, 0x4c, 0x96, 0x33, 0xbb, 0xb5, 0xc2, 0xa4, 0x75, 0x4d, 0xfc,
    0xfc, 0x6e, 0x6c, 0x4f, 0x27, 0x31, 0x0c, 0x5c, 0x06, 0xc6, 0xbb, 0x72,
    0xea, 0xb7, 0x9f, 0x8e, 0x84, 0xb9, 0x5d, 0x5b, 0x4c, 0xec, 0x8c, 0x4f,
    0xc2, 0x1e, 0x68, 0xef, 0x43, 0x1a, 0xe6, 0xc7, 0xe4, 0x31, 0xe0, 0xb2,
    0x40, 0xf7, 0xc8, 0x36, 0xef, 0x8f, 0x2b, 0x63, 0x61, 0xcf, 0xe6, 0x9c,
    0xda, 0xe4, 0x92, 0x4c, 0x4b, 0x65, 0xaa, 0xb1, 0x7a, 0xcb, 0x33, 0x07,
    0xdc, 0x00, 0xae, 0x02, 0xb5, 0x7b, 0xd5, 0xd7, 0x9f, 0xfe, 0xfc, 0xfb,
    0xec, 0xcb, 0xb9, 0xd7, 0xfc, 0xf9, 0x61, 0x97, 0xde, 0x98, 0xd1, 0xe2,
    0x29, 0x81, 0x7a, 0xaf, 0xf7, 0x55, 0xe9, 0xa5, 0xf4, 0x00, 0x97, 0x80,
    0x53, 0xad, 0x81, 0xcc, 0x5c, 0x1c, 0x09, 0x6b, 0x13, 0x83, 0xfe, 0x50,
    0x60, 0x24, 0xac, 0x27, 0xb8, 0x59, 0xd2, 0x00, 0x06, 0xf8, 0x18, 0xb8,
    0x00, 0x1c, 0x6f, 0x0b, 0xe5, 0xd6, 0x0f, 0xa3, 0xd9, 0xe7, 0x13, 0xe5,
    0xcc, 0xb0, 0x6f, 0x24, 0x48, 0x0a, 0x6c, 0xa6, 0xb4, 0xc5, 0x00, 0x15,
    0xe6, 0xe5, 0x8f, 0xe5, 0xb3, 0x72, 0x73, 0x7a, 0x7f, 0x76, 0x76, 0xa2,
    0xec, 0x0f, 0xc5, 0xc9, 0xaf, 0x05, 0x69, 0x8b, 0xc7, 0x7f, 0xf2, 0x47,
    0xf3, 0x59, 0x75, 0xf3, 0xbb, 0x4a, 0x58, 0x9b, 0x1c, 0xf4, 0xfb, 0xf2,
    0x59, 0xf5, 0xd6, 0x3f, 0xcd, 0x5a, 0x92, 0xb6, 0x58, 0xf9, 0xf3, 0xc0,
    0x11, 0xad, 0x98, 0xeb, 0xca, 0xe9, 0xbb, 0x87, 0x4a, 0xfe, 0x8b, 0xd3,
    0x3b, 0x83, 0xc2, 0x40, 0xa7, 0xb7, 0x65, 0x2d, 0x4a, 0x2f, 0x66, 0x33,
    0xb0, 0x1b, 0x18, 0x01, 0x0e, 0x02, 0x25, 0xa0, 0xe5, 0x5f, 0x01, 0x2a,
    0xa9, 0x39, 0xae, 0xff, 0x43, 0xdf, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
    0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const char* const img9_rooms[] = { 
"23 31 45 1",
"Q c #0075ee",
"P c #0879ee",
"d c #73aee6",
"c c #7bb2ee",
"# c #83b6e6",
"e c #83b6ee",
"f c #83bae6",
"b c #83baee",
"g c #8bbae6",
"a c #8bbaee",
"i c #8bbeee",
"h c #94beee",
"k c #94c2ee",
"j c #9cc2ee",
"l c #9cc2f6",
"m c #9cc6ee",
"q c #a4c6ee",
"o c #a4c6f6",
"p c #a4caee",
"n c #a4caf6",
"s c #acceee",
"r c #accef6",
"t c #b4d2f6",
"w c #b4d6f6",
"u c #bdd6f6",
"v c #bddaf6",
"x c #c5daf6",
"y c #c5daff",
"z c #c5def6",
". c #c5deff",
"A c #cddef6",
"B c #cddeff",
"D c #cde2f6",
"E c #cde2ff",
"C c #d5e2ff",
"F c #d5e6ff",
"H c #deeaf6",
"G c #deeaff",
"J c #deeeff",
"I c #e6eeff",
"K c #e6f2ff",
"L c #eef2ff",
"N c #eef6ff",
"M c #f6f6ff",
"O c #ffffff",
".......................",
"#a#b#a#b#a#b#a#b#a#b#a#",
"cdcdcdcdcdcdcdcdcdcdcdc",
"#e#e#e#e#e#e#e#e#e#e#e#",
"aeb#aeb#aeb#aeb#aeb#aeb",
"#e#e#e#e#e#e#e#e#e#e#e#",
"aeaeabababababababaeaea",
"fagafafafafafagafagafag",
"hihihihihihihihihihihih",
"ihihhhhhhhhhhhhhhhhhihi",
"jklkjklkjklkjklkjklkjkl",
"kjjmjmjmjmjmjmjmjmjmkmj",
"nmnmomomomomomomomomomo",
"pnpnpnqnqnqnqnqnqnqnpnp",
"rsrrrsrrrsrrrsrrrsrrrsr",
"stststststststststststs",
"utututututututututututu",
"uuuuuuuuuuuvuvuvuvuuuuw",
"xvyxxvyxxvyxxvyxxvyxxvy",
"zAzBzzxBxzxBxzxBxzxBxzx",
"CDEDEDEDEDEDEDEDEDEDCDE",
"DFDFDFDFDFDFDFDFDFDFDFD",
"GFGFGFGFGFGFGFGFGFGFGFG",
"HGGGHGGGHGGGHGGGHGGGHGG",
"IGIGIGIGIGIGIGIGIGIGIGI",
"JIJIJIJIJIJIJIJIJIJIJIJ",
"KILIKILIKILIKILIKILIKIL",
"KLKLKLKLKLKLKLKLKLKLKLK",
"MNMNMNMNMNMNMNMNMNMNMNM",
"OOOOOOOOOOOOOOOOOOOOOOO",
"PQPQPQPQPQPQPQPQPQPQPQP"};

static const char* const img10_rooms[] = { 
"11 31 48 1",
"d c #0075e6",
"h c #0075ee",
"T c #0079ee",
"# c #0879ee",
"f c #73aee6",
"e c #7bb2ee",
"a c #83b6e6",
"g c #83b6ee",
"i c #83bae6",
"c c #83baee",
"j c #8bbae6",
"b c #8bbaee",
"l c #8bbeee",
"k c #94beee",
"n c #94c2ee",
"m c #9cc2ee",
"o c #9cc2f6",
"p c #9cc6ee",
"s c #a4c6ee",
"q c #a4c6f6",
"t c #a4caee",
"r c #a4caf6",
"v c #acceee",
"u c #accef6",
"w c #b4d2f6",
"y c #b4d6f6",
"x c #bdd6f6",
"z c #bddaf6",
"A c #c5daf6",
"B c #c5daff",
"C c #c5def6",
". c #c5deff",
"G c #cddef6",
"E c #cde2f6",
"D c #cde2ff",
"H c #d5e2f6",
"F c #d5e2ff",
"I c #d5e6ff",
"L c #d5eaf6",
"K c #deeaf6",
"J c #deeaff",
"N c #deeeff",
"M c #e6eeff",
"O c #e6f2ff",
"P c #eef2ff",
"R c #eef6ff",
"Q c #f6f6ff",
"S c #ffffff",
"..........#",
"abacabacabd",
"efefefefef#",
"agagagagagh",
"bgcabgcabg#",
"agagagagagd",
"bcbcbcbcbc#",
"ibjbibjbibh",
"klklklklkl#",
"lklklklkkkd",
"mnonmnonmn#",
"npmmnpmpnph",
"qprprpqpqp#",
"srsrsrtrtrd",
"uvuuuvuuuv#",
"vwvwvwvwvwh",
"xwxwxwxwxy#",
"xxxxxzxxxxd",
"AzBAAzBAAz#",
"ACA.ACA.ACh",
"DEDEFEDEDG#",
"HIEIEIEIHId",
"JIJIJIJIJI#",
"KJJJKJJJLJh",
"MJMJMJMJMJ#",
"NMNMNMNMMMd",
"OMPMOMPMPM#",
"OPOPOPOPOPh",
"QRQRQRQRQh#",
"SSSSSSSShTO",
"#h#h#h#h#OR"};

static const char* const img11_rooms[] = { 
"81 28 552 2",
"#m c #047dad",
"eT c #0a83b4",
"eA c #0b6387",
"cr c #0b85b7",
"eE c #0c90c5",
"eS c #0f80ac",
"c9 c #1089ba",
"dp c #1090c3",
"#H c #1095ca",
"dl c #109fdb",
"aW c #119ad1",
"ei c #126c93",
"#n c #1280ad",
"an c #1296ca",
"dm c #129cd4",
"d3 c #136c8f",
"dL c #136e8f",
"cd c #1385b2",
"eU c #138aba",
"#V c #1396c9",
"aO c #1396ca",
"ej c #146485",
"eD c #14769f",
"fn c #148ebc",
"#l c #1490c0",
"b. c #1496ca",
"#o c #1498ce",
"eB c #156889",
"eR c #15789f",
"ez c #1586b3",
"eu c #1589b9",
"br c #1597cb",
"f# c #1686b4",
"eM c #177aa4",
"ev c #178cbb",
"bI c #1797cb",
"bf c #1797cd",
"c5 c #17abe6",
"eC c #186a8e",
"ek c #186b8e",
"fa c #1886b2",
"cT c #188bb9",
"cD c #1892c2",
"b2 c #1897cb",
"ci c #1898cb",
"d4 c #19769a",
"dM c #19769c",
"dt c #19789f",
"fS c #1980a9",
"az c #1993c3",
"#9 c #1998cb",
"bW c #199acb",
"eQ c #1a779c",
"fo c #1a96c8",
"be c #1aa8e2",
"e5 c #1b7ea4",
"eN c #1b82ac",
"fs c #1b8ab7",
"ea c #1b98cb",
"#L c #1b98cd",
"cx c #1b9acb",
"da c #1c80a9",
"cV c #1c82ab",
"cF c #1c85af",
"cE c #1c87b2",
"ft c #1c8ebb",
"bV c #1c90be",
"#8 c #1c9acb",
"cL c #1c9acd",
"db c #1c9cce",
"#x c #1ca1d6",
"fu c #1d8bb9",
"e6 c #1e82ab",
"e7 c #1e85af",
"eK c #1e8cb7",
"e0 c #1e97c8",
"e# c #1e9aca",
"aA c #1e9cce",
"bh c #1e9ccf",
"cG c #1e9cd0",
"ct c #1e9dcf",
"d5 c #1e9dd0",
"dN c #1e9dd1",
"## c #1eaae2",
"fT c #1f80a9",
"cU c #1f86b2",
"fv c #1f87b3",
"cs c #1f89b3",
"e4 c #1f8ebb",
"bg c #1f93c0",
"c0 c #1f9bcd",
"cW c #1f9ccf",
"ce c #1f9dcf",
"eo c #1f9dd0",
"#a c #1faae2",
"e8 c #2089b4",
"eL c #208ebb",
"f. c #2092bf",
"es c #2094c1",
"eJ c #2095c3",
"et c #2095c5",
"fr c #2095c7",
"eF c #2098c9",
"dg c #209bcd",
"d7 c #20a1d5",
"c4 c #20b1eb",
"fR c #218ab4",
"er c #2197c7",
"dz c #219cce",
"dT c #219fd5",
"el c #21a1d4",
"aX c #2295c5",
"#G c #229bca",
"e2 c #229dcf",
"dA c #229ed1",
"dP c #22a4d7",
"#z c #22a5db",
"dk c #22ace4",
"d2 c #2384a9",
"e9 c #238db9",
"ds c #238fba",
"bC c #2395c2",
"d. c #239ac9",
"cS c #239ccb",
"dS c #239cce",
"e. c #239dcf",
"eI c #239dd0",
"eq c #239ed0",
"d9 c #23a1d1",
"dR c #23a1d4",
"e3 c #23a2d2",
"fq c #23a2d6",
"eH c #23a5db",
".4 c #259ccd",
"fp c #25a1d1",
"dq c #25a2d5",
"e1 c #25a2d6",
"ep c #25abdf",
"fU c #2682a6",
"fb c #2690ba",
"#K c #2697c6",
"d# c #2698c8",
"dy c #26a2d2",
"#A c #26a6dc",
"ew c #26abdf",
"cO c #26b3eb",
"fw c #2788b1",
"df c #27a2d4",
"dh c #27a3d5",
"dw c #27a5d9",
"d8 c #27b2e6",
"bz c #27b2e8",
"cj c #28aadf",
"eP c #299ac5",
"cK c #29a3d4",
"c1 c #29a8db",
"#b c #29b2e8",
"#p c #2aa1d0",
"em c #2aa2d2",
"cw c #2aa3d4",
"bA c #2aafe2",
"dQ c #2ab5ec",
"eO c #2ca3d4",
"dd c #2ca9dc",
"#B c #2caadb",
".3 c #2caadd",
"#y c #2cabde",
"aY c #2da2d1",
"aB c #2da3d1",
"dc c #2da3d2",
"#W c #2da5d6",
"a. c #2ea2d1",
"bX c #2ea3d1",
"#M c #2ea3d2",
"dO c #2ea4d2",
"du c #2ea4d4",
"ch c #2ea4d5",
"#I c #2ea6d6",
"#C c #2ea8d8",
"#F c #2fa1ce",
"b1 c #2fa4d5",
"bH c #2fa5d5",
"cy c #2fade0",
"bS c #2fb3e8",
"bq c #30a5d6",
"#w c #30aadc",
"#c c #30b8ee",
"ey c #30bcf3",
"ex c #30c0f9",
"fV c #317a99",
"eV c #3191b6",
"#k c #31a3d2",
"a9 c #31a5d5",
"#D c #31a6d4",
"aN c #31a6d5",
"cY c #31acdd",
"b3 c #31afe0",
"dj c #31b4e8",
"dx c #31b8ee",
"dB c #32a9d9",
"bR c #32b8ec",
"#4 c #32b8ed",
"di c #34afe0",
"#E c #35a4d0",
"am c #35a8d6",
"#3 c #35b4e8",
"fx c #3688ab",
"eh c #3694b8",
"eb c #36a3d0",
"cI c #36adde",
"dr c #36b4e7",
"c2 c #36b8ec",
"ao c #37b2e4",
"cN c #37bbf2",
"#U c #38a9d6",
"ay c #38afde",
"c3 c #38bbf2",
"dU c #39b0e0",
"bJ c #39b2e3",
"b8 c #39bbee",
"de c #39bbf1",
"#d c #39bef3",
".5 c #3b9bc2",
"dG c #3baddb",
"cu c #3bb1e0",
"cz c #3bbcef",
"bs c #3cb4e4",
"#Z c #3db1de",
"aP c #3db7e6",
"ee c #3dbef2",
"dK c #3eabd6",
"#j c #3eb1de",
"#2 c #3eb7e6",
"cg c #3fb3e2",
"b# c #40b5e6",
"fW c #42758b",
"en c #429abe",
"fc c #429bbd",
"#Y c #42b0dd",
".2 c #43b1dd",
".T c #43b9e7",
"cZ c #43c0f2",
"#e c #43c2f5",
"c8 c #44afd7",
"#X c #44afdb",
"cM c #44c0f1",
"eG c #459bbe",
"do c #45b0db",
"#0 c #45b5e3",
".U c #45bbea",
"ef c #45c6f8",
"a# c #469dbf",
"cc c #46abd5",
"dF c #46b2dd",
"bZ c #46b5e3",
"#1 c #46b7e3",
"bN c #46c0f1",
"ed c #46c6fa",
"aZ c #479ec1",
"aC c #479fc1",
".H c #47afd9",
"#N c #489fc1",
"dH c #48b5e2",
"#q c #499fc1",
"d6 c #49a0c1",
"bB c #4ab5df",
"bF c #4ab8e4",
"b7 c #4ac3f2",
"#i c #4bbcea",
"cJ c #4bc3f4",
"cA c #4cc3f5",
"#f c #4cc6f6",
"fy c #4d89a2",
"#. c #4dc2f1",
"bo c #4eb9e5",
".V c #4ec2f1",
".S c #4fbce8",
"dC c #4fbfeb",
"#5 c #51c6f5",
".G c #52bfeb",
"eg c #52c3f2",
"#g c #52c7f5",
"fX c #537484",
"a7 c #53bbe5",
"#u c #53bbe6",
"ec c #53c0ec",
"#h c #53c3f1",
"b9 c #53c6f4",
"cv c #53c6f5",
".9 c #55b9e3",
"dE c #56bce5",
"aL c #56bee6",
".1 c #56c0ea",
"c. c #56c7f3",
".R c #58bee5",
"bv c #58c8f4",
"dn c #59bce4",
"dD c #59c3ed",
"b6 c #59c9f6",
".W c #59caf6",
"gf c #5a707b",
"ak c #5abfe7",
"gg c #5b6972",
"aa c #5c5c5c",
"bM c #5dcaf6",
"fd c #5e98b0",
"gh c #5f676e",
"#S c #60c3eb",
"fY c #617783",
".B c #61c3ec",
".C c #61c6ee",
"#J c #62bfe4",
"gi c #63676c",
".X c #63d0fc",
"fz c #648696",
"eW c #6495a9",
"b0 c #64cff8",
".Q c #66c0e4",
"dI c #68cbf3",
"bK c #68cff9",
"gj c #696c72",
"bO c #69d0f8",
"fQ c #6abfe0",
"aV c #6acbf4",
".D c #6acef5",
"b4 c #6ad0f8",
"fZ c #6b7881",
"ck c #6bd0f9",
"bL c #6bd1fb",
".Y c #6bd5ff",
"bG c #6cd1fb",
".0 c #6cd2fc",
"fe c #6d8895",
".A c #6ec9ed",
"at c #6fd4fc",
"fA c #708088",
"ge c #70858f",
"c# c #70d1f9",
"ff c #717a81",
"bu c #71d5fb",
".Z c #71d6ff",
"f0 c #72787e",
"bt c #72d5fb",
"bi c #73757b",
".I c #73b9d5",
"bb c #73d4fb",
"a0 c #75777b",
"gk c #75777d",
"bp c #75d5fc",
"ba c #75d6fc",
".z c #76c8e8",
".E c #76d6fc",
"as c #76d6fd",
".F c #76d8fe",
"fB c #777f84",
"eX c #77909b",
"dJ c #77dcff",
"aD c #78787b",
"fg c #797d83",
"b5 c #79d7fd",
"#r c #7a7a7a",
"aQ c #7ad9fe",
"bw c #7bd8fb",
"dY c #7bd8fd",
"a8 c #7dd8fd",
"gl c #7f8188",
"fC c #808489",
"dV c #80d7f9",
"c6 c #80d8fc",
"aM c #81dbfe",
"f1 c #82858b",
"cq c #82d0ee",
".k c #82d2f2",
"eY c #83858c",
"#v c #84ddff",
"dX c #86ddff",
"gm c #878990",
".P c #87cde8",
"cP c #87ddfe",
"al c #87ddff",
".y c #88cce7",
"ap c #88deff",
"au c #88dfff",
"fD c #8c8e95",
"fh c #8d9097",
"dZ c #8de0ff",
"gn c #8e9198",
".6 c #8f8f8f",
".j c #90d3ef",
".l c #90d4ed",
"f2 c #91939a",
"gd c #939ba0",
"go c #95979f",
"#T c #95e3ff",
"d1 c #96e0fd",
"ar c #9ae6ff",
"gp c #9d9fa7",
"bd c #9ee6ff",
"ab c #a0a0a0",
"f3 c #a1a3ab",
"fE c #a1a4ac",
"dW c #a1ebff",
"bc c #a2e8ff",
"bT c #a3e8ff",
"gq c #a4a6af",
".x c #a4d7eb",
".O c #a4dcf2",
".i c #a7daee",
"gc c #a8abb3",
"#7 c #a9ebff",
"by c #a9ecff",
"gr c #aaadb5",
".N c #aadbf0",
"#R c #abd7e6",
"cC c #ace6ff",
"f4 c #aeb0b9",
"gs c #aeb1ba",
"fi c #b0b3bc",
"bU c #b0e8ff",
"co c #b0eeff",
"d0 c #b0f6ff",
"gt c #b2b5be",
"av c #b2f1ff",
"gb c #b3b6bf",
"#O c #b7b7b7",
"cf c #b7e2f5",
"#t c #b7e7f9",
"cB c #b7f1ff",
"cn c #b7f2ff",
".w c #b8dfee",
"a6 c #b8e2f5",
"cH c #b8e3f5",
"fm c #b8e4f7",
"fF c #b9bcc5",
"dv c #b9e2f5",
"cX c #b9e3f5",
"aK c #b9e4f5",
"gz c #bababa",
"f5 c #babcc6",
"aj c #bae3f5",
"g. c #bbbec6",
".m c #bbdbe9",
".h c #bce2f3",
"aR c #bcf4ff",
"aq c #bcf5ff",
"#6 c #bcf6ff",
"gu c #bdbfc7",
".v c #bddfed",
"#P c #bebebe",
"fM c #bec1cb",
"#Q c #bfbfbf",
"ga c #c0c2ca",
"cp c #c1f6ff",
"ac c #c2c2c2",
"cl c #c3f8ff",
".J c #c4c4c4",
"bY c #c4c7d1",
"gy c #c5c5c5",
"bE c #c5c8d2",
"cR c #c5f6ff",
"gA c #c7c7c7",
"bQ c #c7f8ff",
"bj c #c8cbd5",
".f c #c9e4ef",
".g c #c9e6f3",
"ca c #c9fbff",
"a1 c #cbcdd5",
"bl c #cbcfd9",
"fG c #ccd0da",
"fP c #ccdfe3",
"eZ c #cdd1db",
".M c #cdeaf5",
"aE c #cfd0d5",
"f9 c #cfd3dd",
"f6 c #d0d2dd",
"gB c #d1d1d1",
"ad c #d2d2d2",
".u c #d3ebf3",
".8 c #d3f3fb",
"#s c #d4d4d4",
".n c #d4e5ec",
"f7 c #d5d8e2",
"cm c #d5ffff",
"f8 c #d7dae5",
"fL c #d8dbe6",
".7 c #dcdcdc",
"fj c #dce0eb",
"fO c #dde0e9",
"fH c #dde1ec",
"gx c #e0e0e0",
"g# c #e0e1e6",
"fk c #e0e4ef",
"a3 c #e1e5ef",
"bD c #e1e5f0",
".e c #e2f2f8",
"ax c #e2ffff",
"bP c #e4ffff",
"bk c #e5e9f4",
"bx c #e5ffff",
"gC c #e6e6e6",
"af c #e6e7ea",
"ae c #e8e8e8",
"fN c #e8ebf2",
"gv c #eaeaed",
"aH c #eaedf3",
"fI c #eaeefa",
"aw c #eaffff",
"fK c #ebeffb",
".t c #edf8f9",
".K c #eeeeee",
"fJ c #eef2fe",
"gD c #efefef",
"a5 c #eff3ff",
"cb c #efffff",
"fl c #f0f4fe",
".s c #f0f8fa",
"a2 c #f1f4ff",
"bn c #f1f5ff",
".o c #f2f2f2",
"a4 c #f2f6ff",
"gI c #f3f3f3",
"aJ c #f3f6ff",
"gE c #f4f4f4",
"bm c #f4f7ff",
".d c #f4fafb",
"c7 c #f4ffff",
"gH c #f5f5f5",
"aU c #f5ffff",
"gJ c #f6f6f6",
"aG c #f6f8fe",
"aI c #f6f8ff",
".r c #f6fbfc",
"aT c #f6ffff",
"ag c #f7f9fe",
"aF c #f7f9ff",
"gw c #f8f8f8",
"ai c #f8f9ff",
"ah c #f8faff",
".q c #f8fcfe",
".c c #f9fcfc",
"gK c #fafafa",
".L c #fafdfd",
".b c #fafdfe",
".p c #fbfbfb",
"aS c #fbffff",
"gL c #fcfcfc",
".a c #fcfdfe",
"gF c #fdfdfd",
"cQ c #fdffff",
"gG c #fefefe",
".# c #feffff",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.g.h.i.j.k.l.m.n.o.pQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.q.r.s.t.u.v.w.x.y.z.A.B.C.D.E.F.G.H.I.J.KQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.L.M.N.O.P.Q.R.S.T.U.V.W.X.Y.Z.0.1.2.3.4.5.6.7QtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.8.9#.###a#b#c#d#e#f#g#h#i#j#k#l#m#n#o#p#q#r#sQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#t#u#v#w#x#y#z#A#B#C#D#E#F#G#H#I#J#K#L#M#N#r#sQtQtQtQtQt",
"#O#P#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#R#S#T#U#V#W#X#Y#Z#0#1#2#3#4#5#6#7#8#9a.a#aaab#Q#Qacadae",
"afagahaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiaiajakalamanaoapaqaras.0atauavawaxayazaAaBaCaDaEaiaFaGaHaf",
"ahaIaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaJaKaLaMaNaOaPaQaRaSaTawaUQtQtQtaVaWaXaAaYaZa0a1aJaJaJa2a3",
"aIa4a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a6a7a8a9b.b#babbbcQtQtQtQtQtbdbebfbgbhaBaCbibja5a5a5bkbl",
"bmbna5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a6bobpbqbrbsbtbubvbwbxQtQtbybzbAbBbC#L#MaCbibja5a5a5bDbE",
"bmbna5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a6bFbGbHbIbJbKbLbMbNbObPbQbRbSbTbUbVbWbXaCbibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a6bZb0b1b2b3b4b5b6b7b8b9c.c#cacbcccdceaBaCbibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5a5aaaaaaaaa5a5a5aaaaaaaaaaa5a5a5aaaaaaaaaaa5a5a5a5aaaaaaa5a5a5a5a5a5a5a5a5a5a5a5a5a5cfcgbMchcicjckclcmcncocpawQtQtcqcrcsct#MaCbibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5aaaaa5a5a5aaa5a5aaaaa5a5aaaaa5a5aaaaa5a5a5a5a5a5a5aaaaaaa5a5a5a5a5a5a5a5a5a5a5a5a5a5a6cucvcwcxcyczcAcBQtQtQtQtQtcCcDcEcFcG#MaCbibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5aaaaa5a5a5a5a5a5aaaaa5a5aaaaa5a5aaaaa5a5a5a5a5a5aaaaa5aaaaa5a5a5a5a5a5a5a5a5a5a5a5a5cHcIcJcKcL#ycMcNcOcPcQQtQtcRcScTcUcVcW#MaCbibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5aaaaa5a5a5a5a5a5aaaaaaaaaaa5a5a5aaaaaaaaaaa5a5a5aaaaa5aaaaa5a5a5a5a5a5a5a5a5a5a5a5a5cXcYcZcKc0c1c2c3c4c5c6c7bxc8c9d.d#dadbdcaCbibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5aaaaa5a5a5a5a5a5aaaaaaaaa5a5a5a5aaaaa5a5a5a5a5aaaaaaaaaaaaaaa5a5a5a5a5a5a5a5a5a5a5a5cXdddedfdgdhdidjdkdldmdndodpdqdrdsdtcGduaCbibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5aaaaa5a5a5aaa5a5aaaaa5aaaaa5a5a5aaaaa5a5a5a5a5aaaaa5a5a5aaaaa5a5a5a5a5a5a5a5a5a5a5a5dvdwdxdydzdAdBdCdDdEdFdGdHdIdJdKdLdMdNdOaCbibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5a5aaaaaaaaa5a5a5aaaaa5a5aaaaa5a5aaaaaaaaaaa5a5aaaaa5a5a5aaaaa5a5a5a5a5a5a5a5a5a5a5a5a6dPdQdRdSdAdTdUdVdWdXdYdZd0d1d2d3d4d5dud6bibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5cHd7d8d9e.cSe#eaebecedeeefegeheiejekelemenbibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a6eoepeqeqereseteuevewexeyezeAeBeCeDeEeFeGbibja5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a6c0eHeIeqeJeKeLcEeMeNeOePeQeReSeTeUeVeWeXeYeZa5a5a5bDbY",
"bmbna5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5cfe0e1e2e3e4e5e6e7e8e9f.f#fafbfcfdfefffgfhfifja5a5a5fkbY",
"bmfla5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5a5fmfnfofpfqfrfsftfufvfwfxfyfzfAfBfCfDfEfFfGfHfIa5fJfKfLfM",
"fNfOfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfLfPfQfRfSfTfUfVfWfXfYfZf0fgf1f2f3f4f5bEf6f7f8fLfLf8f9fMg.",
"g#gagbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgbgcgdgegfggghgigjgkglgmgngogpgqgrgsfigtgbgbgbgbgbgbgbgugv",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtgwgxgygz#QgAgB.7gCgDgEgw.pgFgGQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtgG.pgH.ogIgJgKgLgGgGQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt"};

static const char* const img12_rooms[] = { 
"11 23 30 1",
"B c #0276e7",
"d c #0578e7",
"f c #0b7be8",
"A c #117ee8",
"v c #137fe9",
"y c #298beb",
"c c #3591ec",
"b c #5ba6ef",
"m c #61a8f1",
"p c #6aaef1",
"l c #73b3f2",
"s c #85bdf3",
"e c #a0cbf6",
"g c #a6cdf8",
"w c #a6cff7",
"t c #add1f8",
"a c #afd3f7",
"x c #b1d3f8",
"q c #c9dffb",
"r c #dae8fd",
"o c #deedfc",
"h c #e6eefe",
"n c #edf2ff",
"i c #eef2ff",
"z c #eef3ff",
"j c #eff3ff",
"k c #f6fafe",
"u c #f9fcfe",
"# c #fcfdff",
". c #ffffff",
"......#abcd",
".....efghij",
"...klmnjjjj",
"..opqjjjjjj",
"..prjjjjjjj",
".stjjjjjjjj",
"uvjjjjjjjjj",
"wxjjjjjjjjj",
"bhjjjjjjjjj",
"yzjjjjjjjjj",
"Ajjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj",
"Bjjjjjjjjjj"};

static const char* const img13_rooms[] = { 
"24 23 5 1",
"# c #0075ee",
". c #0879ee",
"c c #eef2ff",
"a c #f6f2ff",
"b c #f6f6ff",
".#.#.#.#.#.#.#.#.#.#.#.#",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb"};

static const char* const img14_rooms[] = { 
"11 23 29 1",
"A c #0276e7",
". c #0578e7",
"z c #0879e8",
"i c #0b7be8",
"u c #137fe9",
"y c #2388ea",
"# c #3591ec",
"a c #5ba6ef",
"l c #61a8f1",
"p c #6aaef1",
"m c #73b3f2",
"t c #8ec2f4",
"j c #a0cbf6",
"h c #a6cdf8",
"x c #a6cff7",
"s c #add1f8",
"b c #afd3f7",
"w c #b1d3f8",
"o c #c9dffb",
"r c #dae8fd",
"q c #deedfc",
"g c #e6eefe",
"k c #edf2ff",
"f c #eef2ff",
"e c #eff3ff",
"n c #f6fafe",
"v c #f9fcfe",
"c c #fcfdff",
"d c #ffffff",
".#abcdddddd",
"efghijddddd",
"eeeeklmnddd",
"eeeeeeopqdd",
"eeeeeeerpdd",
"eeeeeeeestd",
"eeeeeeeeeuv",
"eeeeeeeeewx",
"eeeeeeeeega",
"eeeeeeeeeey",
"eeeeeeeeeez",
"eeeeeeeeeeA",
"eeeeeeeeeeA",
"eeeeeeeeeeA",
"eeeeeeeeeeA",
"eeeeeeeeeeA",
"eeeeeeeeeeA",
"eeeeeeeeeeA",
"eeeeeeeeeeA",
"eeeeeeeeeeA",
"eeeeeeeeeeA",
"eeeeeeeeeeA",
"eeeeeeeeeeA"};

static const char* const img15_rooms[] = { 
"60 18 45 1",
"N c #414041",
"K c #5a9dde",
"M c #5a9de6",
"L c #5aa1e6",
"I c #62a1e6",
"H c #62a5e6",
"E c #6aa5e6",
"J c #6aa5ee",
"F c #6aaae6",
"G c #6aaaee",
"C c #73aae6",
"B c #73aee6",
"A c #73aeee",
"D c #7baeee",
"y c #7bb2e6",
"z c #7bb2ee",
"x c #83b6ee",
"u c #8bbaee",
"w c #8bbeee",
"v c #94beee",
"t c #9cc2ee",
"s c #9cc6f6",
"r c #a4c6ee",
"p c #a4caee",
"q c #a4caf6",
"n c #accef6",
"o c #acd2f6",
"m c #b4d2f6",
"l c #b4d6f6",
"Q c #bdbebd",
"k c #bdd6f6",
"O c #c5bec5",
"P c #c5c2c5",
"j c #cde2f6",
"h c #cde2ff",
"g c #d5e2ff",
"i c #d5e6ff",
"d c #deeaff",
"f c #deeeff",
"e c #e6eeff",
"b c #eef6ff",
"a c #f6f6ff",
"c c #f6faff",
"# c #fffaff",
". c #ffffff",
"............................................................",
"#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.",
"abaacbaaabaaabcaabcacbaacbaaabcaabaacbaaabcaabaaabaaabaacbca",
"dedefededefefefededefefededefedefededefededededefefedededefe",
"ghijihijihijihgjihgjghijghijghijihihihijihijghijihihihijihij",
"kklkkkkkkklkkklkkklkkkkkkklkkkkkkklkkkkkkkkkkklkkklkkkkkkkkk",
"mnmnmnmnmnmnmnmnmomnmnmnmnmnmnmnmomnmnmnmnmnmnmnmnmnmnmnmnmn",
"pqpqrqpqrqpqrqpqpqrqpqpqpqrqpqpqpqpqpqpqpqpqpqrqpqrqpqpqpqpq",
"stststststststststststststststststststststststststststststst",
"uvwvuvuvwvuvuvuvwvuvwvuvwvwvuvwvuvuvwvwvwvuvuvuvuvuvwvuvuvwv",
"uxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxux",
"yzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyz",
"ABABACABABACABABABACABABDCABDBACABABABABABABABACABABABABABAB",
"EFEFEFEFEFEFEGEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEGEFEGEFEGEF",
"HIJIHIJIHIJIHIJIHIJIHIJIHIJIEIJIEIJIHIJIHIJIEIJHEIJIHIJIEIJI",
"KLMIMIMIMLMIMLMIMLMIMLMIMLMIMIMIMIMIKIMIMLMIMIMIMLMIMLMIMLMI",
"NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN",
"OPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQP"};

static const char* const img16_rooms[] = { 
"34 21 3 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"......#...........................",
"..................................",
"..................................",
"..................................",
"..................................",
"....a...................#.........",
"..................................",
".....................a............"};

static const char* const img17_rooms[] = { 
"108 21 18 1",
". c #004991",
"# c #004a91",
"p c #004a92",
"h c #034c95",
"k c #065099",
"f c #08539e",
"m c #0b57a2",
"o c #0e5aa6",
"a c #115eaa",
"d c #1361ae",
"i c #1665b2",
"g c #1968b6",
"j c #1c6cbb",
"c c #1e6fbf",
"n c #2172c3",
"e c #2476c7",
"l c #2779cb",
"b c #297dcf",
"......................................................................................................#.....",
"............................................................................................................",
"............................................................................................................",
"............................................................................................................",
"............................................................................................................",
".......abbbbbbbc.dbe.........................................fcbbbgh........................................",
".###...ibbbbbbbi.gbj........................................klbbbbbe...fjm.............#....................",
".......cbd.......ebd........................................ibn..keba.kbl...................................",
".......lbm.......lbo.hgbbbd..dbggbbc...fcbbck..kjbbld.......ibj......dbbbbkfcbbla..mbedlbnk.cbbbbbi.hgbbbd..",
"......kbbbbbbbc.mbbkhnbbbbbd.gbbbbbba.obbbbbe.klbbbbbd......fbbnd....jbbbehlbbbbbf.abbbbbbg.lbbbbbdhnbbbbbd.",
"......mbbbbbbbg.abe.ibch.jbj.ebef.nba.ebc.klbmcbnk.ibl.......fcbbld...cba......ebo.gbba.ibg...hcbc.ibch.jbj.",
"......dbc.......gbc.ebbbbbbg.lbo..lbmmblh....hbbo..fbbh........kgbbd..lbk..dicbbbk.cbi..cbd..knbc..ebbbbbbg.",
"......gbd.......nbd.lbo.....fbl..fbl.dbn.....fbbh..dbl.....nbd...dbj.mbl..nbghabe..lbm..lbm.kebj...lbo......",
"......nba.pp....lba.ebj.oblhabn..abe.abehhnbg.lbd.febi.....gbnh.hnbg.dbc.kblhhnbg.kbbh.kbbkflbi...pebj.oblh.",
"......lbbbbbbbafbbk.abbbbbd.ibg..dbg.hebbbbeh.gbbbbbnh.....fbbbbbblk.ibbl.lbbbbbd.obe..mbe.ebbbbbg.abbbbbd..",
".....kbbbbbbbbkabl...aebld..cbd..cbd..fcbbck...dbbbgh.......fcbbbjk..flbe.abbccbd.dbj..dbj.lbbbbba..aebld...",
"................................................................................................p...........",
"............................................................................................................",
"............................................................................................................",
"............................................................................................................",
"............................................................................................................"};

static const char* const img18_rooms[] = { 
"72 21 20 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"b c #004a94",
"m c #004c97",
"h c #004d99",
"l c #004f9c",
"q c #00509d",
"g c #00509f",
"f c #0052a2",
"p c #0053a5",
"e c #0055a8",
"j c #0056aa",
"c c #0057ad",
"i c #0059b0",
"d c #005ab3",
"o c #005cb6",
"n c #005db9",
"r c #005fbb",
"k c #0060be",
"...#...................#................................................",
"........................................................................",
"........................................................................",
"...............................................a........................",
"........................................................................",
"........................................................................",
".......................................................................a",
"..........bcddddde.dddddddf.gdddddddhddddddihbjddddddffdddddddh.........",
"..........ekkkkkkklkkkkkkkkmnkkkkkkklkkkkkkkcfkkkkkkkeokkkkkkkl.........",
"..........dkclllokekkcllpkklkkpllllllkklllckdekolllllmkkclllllb.........",
"..........dke...dkekkefdokkqkkljdddjlkk...ekdekd......kkndddil..........",
"..........dke...dkekkeekkkr.kkldkkkdlkk...ekdekd......kkkkkkkkb.........",
"..........dke...dkekkemlllb.kkl.....lkk...ekdekd......kkdeeckkl.........",
"..........jkkkkkkkfkke......rkkkkkkklkk...ekdpkkkkkkkeokkkkkkkh.........",
"..........lrkkkkknbkke......ekkkkkkklkk...ekdmnkkkkkkegkkkkkkd..........",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................"};

static const char* const img19_rooms[] = { 
"80 28 341 2",
".Y c #0eb8ff",
".K c #10b8ff",
"#f c #14b5f8",
".w c #14b8fd",
"#A c #17baff",
".m c #24bdfd",
".x c #28c0ff",
".n c #2bbffd",
"#U c #2ec2ff",
".l c #30bffb",
"a# c #32bdf8",
".o c #38c2fb",
"as c #39bef7",
"#g c #39c5ff",
"aa c #3ec7ff",
".L c #40c7ff",
"#T c #42bff6",
"bf c #43434c",
"aK c #44c8ff",
"bo c #45454d",
"at c #45c9ff",
"bS c #484952",
".Z c #48c9ff",
"bF c #4b4c54",
".y c #4bcaff",
"aA c #4cc0f2",
"bT c #4d4e57",
"aP c #4f5058",
"bR c #50515a",
"bU c #51525b",
"aT c #53c9fb",
".D c #55cdff",
"aG c #58585f",
"aZ c #585961",
"dm c #585b69",
"#B c #59ceff",
"ax c #5b5e64",
".p c #5bc6f3",
"a1 c #5c5c5c",
"bE c #5c5d62",
"ak c #5d6065",
".C c #60d0ff",
"a8 c #616167",
".J c #63caf8",
".M c #63d1ff",
"bQ c #64656f",
"#4 c #65666c",
"bV c #66676f",
"#h c #67d2ff",
".z c #67d3ff",
".0 c #68d3ff",
"aU c #6ad4ff",
".E c #6cc8ef",
".k c #6cccf6",
"#V c #6dd4ff",
"a4 c #6ed4ff",
".B c #6fd5ff",
"aJ c #72bce1",
"bp c #73737e",
".A c #74d6ff",
".S c #76d6ff",
".N c #77d7ff",
"a3 c #78b8d8",
"#C c #78d7ff",
"bG c #797a85",
"au c #79d8ff",
"ae c #7ad8ff",
"#K c #7b7b83",
"#z c #7bc9ef",
"aC c #7bd8ff",
".1 c #7bd9ff",
".v c #7cd0f6",
"#Z c #7cd8ff",
"aL c #7cd9ff",
".T c #7dd4f8",
"#i c #7dd9ff",
"a9 c #7e7f86",
"af c #7fdaff",
"bb c #80c4e2",
"ad c #80daff",
"bx c #8193a3",
".X c #81cef3",
"#0 c #81daff",
"#E c #82daff",
"#F c #83daff",
"di c #848286",
"#W c #84dbff",
"aB c #85dbff",
"aV c #86dcff",
".O c #87dbff",
"#l c #88dcff",
"bg c #898a97",
".R c #89dcff",
".2 c #89ddff",
"bn c #8a8a8d",
"ab c #8addff",
"#D c #8bddff",
"dq c #8c8c90",
"bP c #8c8e98",
"#Y c #8cddff",
"#j c #8cdeff",
"bW c #8d8f96",
"bk c #8dbbd2",
"#1 c #8dddff",
"ag c #8ddeff",
".8 c #8edeff",
"cn c #8f8b89",
"be c #8f9092",
".7 c #8fdeff",
".P c #90deff",
"#X c #90dfff",
"dp c #919092",
"#q c #919195",
"ac c #91dfff",
"#m c #92deff",
".3 c #92dfff",
"db c #9394ab",
".6 c #93dfff",
".q c #94cae3",
".Q c #94dfff",
"#k c #95e0ff",
"#p c #96b6c3",
".5 c #96e0ff",
".4 c #97e0ff",
".9 c #98d8f2",
".U c #99b1c0",
"c8 c #9a979c",
"#. c #9aa1aa",
"bj c #9aa2b1",
"aS c #9bb0c2",
"#G c #9ce2ff",
"dn c #9d9fa7",
"#n c #9de2ff",
"dj c #a07130",
"dl c #a0a0b7",
"c3 c #a27545",
"bw c #a2a4ad",
"dk c #a37f59",
".F c #a4bdcd",
"dc c #a6a9b2",
"bq c #a7a9b9",
"bH c #aaaebd",
"ba c #aab0be",
"by c #aac7d6",
"cM c #aba9ae",
"#o c #abe6ff",
"#H c #abe7ff",
"cw c #acaaad",
"cX c #acaaaf",
"c9 c #ad7a30",
"cD c #aeacb0",
"cT c #b18b5e",
"#t c #b1b1b1",
"bD c #b2b2b4",
"ay c #b2b5c1",
"bX c #b2b6be",
"cK c #b38d5f",
"#u c #b3b3b3",
"dh c #b3b6bf",
"cY c #b48033",
"al c #b4b7c3",
"da c #b8936f",
"#r c #b8b8b8",
"aH c #b8bac6",
"aM c #b9eaff",
"ah c #b9ebff",
"cB c #ba9260",
"#I c #baeaff",
"cN c #bb8732",
"de c #bbbec7",
"c. c #bbbec9",
"cu c #bc935f",
"#e c #becfdc",
"#s c #bfbfbf",
"c# c #bfc2cc",
"aQ c #c0c3cd",
"b9 c #c0c3ce",
"#J c #c0e4f5",
"cE c #c18b32",
"#c c #c1c1c1",
"ck c #c29963",
"#5 c #c3c5ce",
"ao c #c4c7d1",
".j c #c4e1f2",
"cx c #c69034",
"#d c #c6c6c6",
"bO c #c6c9d3",
"ai c #c6eeff",
"aD c #c6efff",
"bI c #c7c8d6",
"ar c #c7c9d4",
"dg c #c7cad2",
"a0 c #c7cad4",
"#2 c #c7efff",
"dr c #c8c8c8",
"aY c #c8c8c9",
"ca c #cacdd7",
"bz c #cae7f3",
"co c #cb9537",
"#P c #cccccc",
".r c #ccd2d9",
"ce c #cdaf88",
"do c #cdcccb",
"az c #cdcec8",
"#w c #cdcecf",
"dd c #cdd1db",
"bJ c #cea469",
"#8 c #cfcfcf",
"b8 c #d0d4de",
"ap c #d1d1d1",
"#b c #d2d2d2",
"b. c #d2d5e0",
"b0 c #d3b287",
"a2 c #d3d5dc",
"#7 c #d3d6e1",
"#3 c #d3f2ff",
"#v c #d4d4d4",
"bY c #d4d6e0",
"cb c #d5d8e3",
"a. c #d6d8e3",
"c6 c #d7dae5",
"cV c #d8d8d8",
"c7 c #d8dbe6",
"aI c #daddd1",
".V c #dbdbde",
"bZ c #dcd7d8",
"#L c #dcdde2",
"c5 c #dde1ec",
".u c #dedde0",
"a5 c #def5ff",
"bl c #def6ff",
".I c #dfdfe1",
"br c #dfe1ed",
"b7 c #dfe3ee",
"av c #dff5ff",
"aE c #dff6ff",
"bA c #e0f5ff",
"aj c #e0f6ff",
"b4 c #e1bf90",
"an c #e1e5f0",
"bK c #e2900b",
".G c #e2e1e4",
"bh c #e2e6f1",
"bL c #e3bb81",
"cl c #e3e7f1",
"bv c #e3e7f2",
"c2 c #e4a235",
"#S c #e4e5ec",
"cU c #e4e7f2",
"cc c #e4e8f3",
"b3 c #e5920c",
"bC c #e5e8ea",
"bN c #e6e9f5",
"cJ c #e79412",
"bs c #e7d2b6",
"cv c #e7e9f3",
"cj c #e8940c",
"cA c #e89511",
"cS c #e89614",
"## c #e8e8e9",
".d c #e8eaef",
"cC c #e8eaf3",
"cL c #e8eaf4",
"cm c #e8ebf7",
"ct c #e99612",
"#a c #e9e9e9",
".e c #e9e9ee",
".c c #e9ebef",
"bi c #e9ecf7",
"c4 c #e9edf8",
"aN c #e9f8ff",
"aW c #e9f9ff",
".f c #eaeaed",
"aR c #eaeef2",
"a6 c #eaf8ff",
"aw c #eaf9ff",
"#x c #ebecef",
"b6 c #ebeffb",
"b5 c #eceef8",
"d# c #edd79c",
"b# c #edf1fc",
"cd c #edf1fd",
"bu c #eef2fe",
".g c #efeff0",
"bt c #eff1fb",
"bM c #eff2fd",
"am c #eff3ff",
"ci c #f0b13e",
".s c #f0eff1",
".b c #f0f0f3",
"#Q c #f0f2f7",
"#O c #f0f4ff",
"cz c #f1b23f",
"cs c #f1b240",
"b1 c #f1c36b",
"aq c #f1f5ff",
"bB c #f1f9fd",
"cI c #f2b340",
"b2 c #f2b441",
"cW c #f2f5ff",
"cR c #f3b340",
"df c #f3f4f7",
"#y c #f3f4f8",
"#6 c #f3f6ff",
"aF c #f3fbff",
"bc c #f3fcff",
"ds c #f4f4f4",
"#9 c #f4f7ff",
".i c #f5f4f5",
"bm c #f5f5f5",
"ch c #f6d58b",
"cQ c #f6d58c",
"aO c #f6f8fa",
"#N c #f6f8ff",
"cr c #f7d68d",
"cH c #f7d68e",
".a c #f7f7f8",
"#R c #f7f9ff",
".W c #f8f7f8",
"#M c #f8f9ff",
".t c #fafafa",
"cf c #fbd271",
"a7 c #fbfbfb",
"aX c #fbfeff",
"c1 c #fcdd92",
".H c #fcfcfc",
"bd c #fcfeff",
".h c #fdfdfd",
"cq c #fef7c9",
"cy c #fef7ca",
"cP c #fef9ca",
".# c #fefefe",
"cZ c #ffe588",
"cO c #ffe789",
"cF c #ffe988",
"cp c #ffe989",
"d. c #ffeb8d",
"cG c #fff7ca",
"c0 c #fff9ca",
"cg c #fffbcc",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.gQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQt.h.i.j.k.l.m.n.o.p.q.r.s.#QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQt.t.u.v.w.x.y.z.A.B.C.D.E.F.G.HQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQt.I.J.K.L.M.N.O.P.Q.Q.R.S.T.U.V.HQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQt.W.X.Y.Z.0.1.2.3.4.5.6.3.7.8.9#.##.#QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"#a#b#c#d#e#f#g#h#i#j.6#k.6.8#l#l#m#n#o#p#q#r#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#t#u",
"#v#w#x#y#z#A#B#C#D.6.Q.P.O#E#F.8#G#H#I#J#K#L#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#N#O",
"#P#Q#R#S#T#U#V#W#X.6#Y#F#Z#0#1#G#H#I#2#3#4#5#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#O#7",
"#8#9#6a.a#aa#Cabac#Yadaeafag#G#oahai#3ajakalamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqarasatadagag#0auad#1#G#oahai#3avawaxayamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqazaAat#W#1aBaCafag#G#oahaD#3aEawaFaGaHamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqaIaJaKaL.8#0#0#1#G#oaMai#3avaNaFaOaPaQamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqaRaSaTaU.2aV.8#G#Hah#2#3avaWaFaXaYaZa0amamamamamamamamamamamama1a1a1a1amamama1a1a1a1a1amama1a1a1a1a1amamamama1a1a1a1amamamamama1a1a1amamamamamamamamamanao",
"ap#6aqama2a3a4#0.P#G#oahai#3a5a6aFaXa7a8a9b.amamamamamamamamamamama1a1amamama1amama1a1amamamamama1a1amama1a1amama1a1amamama1amamamama1a1a1amamamamamamamamamanao",
"ap#6aqamb#babbag#G#Hah#2#3aEaWbcbdQtbebfbgbhamamamamamamamamamamama1a1amamamamamama1a1amamamamama1a1amama1a1amama1a1amamamamamamama1a1ama1a1amamamamamamamamanao",
"ap#6aqamambibjbk#oaM#2#3blaWaFaXbmbnbobpbqbrbsbtamamamamamamamamama1a1amamamamamama1a1a1a1a1amama1a1a1a1a1amamama1a1amamamamamamama1a1ama1a1amamamamamamamamanao",
"ap#6aqamambubvbwbxbybzbAawbBbCbDbEbFbGbHbIbJbKbLbMamamamamamamamama1a1amamamamamama1a1amamamamama1a1a1a1amamamama1a1amamamamamama1a1a1a1a1a1a1amamamamamamamanao",
"ap#6aqamamambubNbObPbQbRbSbTbUbVbWbXbYbZb0b1b2b3b4b5amamamamamamama1a1amamama1amama1a1amamamamama1a1ama1a1amamama1a1amamama1amama1a1amamama1a1amamamamamamamanao",
"ap#6aqamamamamamb6b7b8b9c.c#aocacbcccdcecfcgchcicjckclamamamamamamama1a1a1a1amamama1a1a1a1a1amama1a1amama1a1amamama1a1a1a1amamama1a1amamama1a1amamamamamamamanao",
"ap#6aqamamamamamamamamamamamamamamamcmcncocpcqcrcsctcucvamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqamamamamamamamamamamamamamamamamamcwcxcpcychczcAcBcCamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqamamamamamamamamamamamamamamamamamamcDcEcFcGcHcIcJcKcLamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"#b#6aqamamamamamamamamamamamamamamamamamamamcMcNcOcPcQcRcScTcUamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"cVcW#ObuamamamamamamamamamamamamamamamamamamamcXcYcZc0c1c2c3aQamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"#ac4c5c6c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c8c9d.d#dadbdcc7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7ddde",
".Hdfdgdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdidjdkdldmdndhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdh",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtdodpdqdr.#QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.HdsQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt"};


/*
 *  Constructs a rooms as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
rooms::rooms( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl ),
      image0( (const char **) img0_rooms ),
      image1( (const char **) img1_rooms ),
      image2( (const char **) img2_rooms ),
      image3( (const char **) img3_rooms ),
      image4( (const char **) img4_rooms ),
      image5( (const char **) img5_rooms ),
      image6( (const char **) img6_rooms ),
      image7( (const char **) img7_rooms ),
      image9( (const char **) img9_rooms ),
      image10( (const char **) img10_rooms ),
      image11( (const char **) img11_rooms ),
      image12( (const char **) img12_rooms ),
      image13( (const char **) img13_rooms ),
      image14( (const char **) img14_rooms ),
      image15( (const char **) img15_rooms ),
      image16( (const char **) img16_rooms ),
      image17( (const char **) img17_rooms ),
      image18( (const char **) img18_rooms ),
      image19( (const char **) img19_rooms )
{
    QImage img;
    img.loadFromData( img8_rooms, sizeof( img8_rooms ), "PNG" );
    image8 = img;
    if ( !name )
	setName( "rooms" );
    setBaseSize( QSize( 0, 0 ) );
    setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    roomsLayout = new QGridLayout( this, 1, 1, 0, 0, "roomsLayout"); 

    layout76 = new QHBoxLayout( 0, 0, 0, "layout76"); 
    spacer114_2 = new QSpacerItem( 16, 12, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout76->addItem( spacer114_2 );

    layout22_2 = new QHBoxLayout( 0, 0, 0, "layout22_2"); 

    pixmapLabel4_4 = new QLabel( this, "pixmapLabel4_4" );
    pixmapLabel4_4->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel4_4->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel4_4->setPixmap( image0 );
    pixmapLabel4_4->setScaledContents( FALSE );
    layout22_2->addWidget( pixmapLabel4_4 );

    pixmapLabel5 = new QLabel( this, "pixmapLabel5" );
    pixmapLabel5->setMinimumSize( QSize( 100, 18 ) );
    pixmapLabel5->setMaximumSize( QSize( 32767, 18 ) );
    pixmapLabel5->setPaletteBackgroundPixmap( image1 );
    pixmapLabel5->setScaledContents( TRUE );
    layout22_2->addWidget( pixmapLabel5 );

    pixmapLabel6_2_2 = new QLabel( this, "pixmapLabel6_2_2" );
    pixmapLabel6_2_2->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel6_2_2->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel6_2_2->setPixmap( image2 );
    pixmapLabel6_2_2->setScaledContents( TRUE );
    layout22_2->addWidget( pixmapLabel6_2_2 );
    layout76->addLayout( layout22_2 );
    spacer114 = new QSpacerItem( 16, 10, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout76->addItem( spacer114 );

    roomsLayout->addLayout( layout76, 6, 0 );

    layout103 = new QVBoxLayout( 0, 0, 0, "layout103"); 

    layout23 = new QHBoxLayout( 0, 0, 0, "layout23"); 

    frame15 = new QFrame( this, "frame15" );
    frame15->setMinimumSize( QSize( 100, 31 ) );
    frame15->setMaximumSize( QSize( 32767, 31 ) );
    frame15->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    frame15->setPaletteBackgroundPixmap( image3 );
    frame15->setFrameShape( QFrame::NoFrame );
    frame15->setFrameShadow( QFrame::Plain );
    frame15->setLineWidth( 0 );
    frame15Layout = new QGridLayout( frame15, 1, 1, 0, 0, "frame15Layout"); 
    spacer38_2 = new QSpacerItem( 40, 18, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame15Layout->addItem( spacer38_2, 0, 0 );

    layout22 = new QVBoxLayout( 0, 0, 0, "layout22"); 
    spacer37_2 = new QSpacerItem( 20, 15, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout22->addItem( spacer37_2 );

    exitButtonPlaceHolder = new QLabel( frame15, "exitButtonPlaceHolder" );
    exitButtonPlaceHolder->setMinimumSize( QSize( 51, 16 ) );
    exitButtonPlaceHolder->setMaximumSize( QSize( 51, 16 ) );
    exitButtonPlaceHolder->setPixmap( image4 );
    exitButtonPlaceHolder->setScaledContents( FALSE );
    layout22->addWidget( exitButtonPlaceHolder );

    frame15Layout->addLayout( layout22, 0, 1 );
    layout23->addWidget( frame15 );

    aboutButtonPlaceHolder = new QLabel( this, "aboutButtonPlaceHolder" );
    aboutButtonPlaceHolder->setMinimumSize( QSize( 28, 31 ) );
    aboutButtonPlaceHolder->setMaximumSize( QSize( 28, 31 ) );
    aboutButtonPlaceHolder->setLineWidth( 0 );
    aboutButtonPlaceHolder->setPixmap( image5 );
    aboutButtonPlaceHolder->setScaledContents( FALSE );
    layout23->addWidget( aboutButtonPlaceHolder );
    layout103->addLayout( layout23 );

    pixmapLabel9_2 = new QLabel( this, "pixmapLabel9_2" );
    pixmapLabel9_2->setMinimumSize( QSize( 100, 22 ) );
    pixmapLabel9_2->setMaximumSize( QSize( 32767, 22 ) );
    pixmapLabel9_2->setPaletteBackgroundPixmap( image6 );
    pixmapLabel9_2->setScaledContents( FALSE );
    layout103->addWidget( pixmapLabel9_2 );

    roomsLayout->addLayout( layout103, 7, 0 );

    layout15 = new QHBoxLayout( 0, 0, 0, "layout15"); 
    spacer9_2 = new QSpacerItem( 15, 16, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout15->addItem( spacer9_2 );

    layout10 = new QVBoxLayout( 0, 0, 0, "layout10"); 

    pixmapLabel6_2 = new QLabel( this, "pixmapLabel6_2" );
    pixmapLabel6_2->setMinimumSize( QSize( 30, 12 ) );
    pixmapLabel6_2->setMaximumSize( QSize( 32767, 12 ) );
    pixmapLabel6_2->setPixmap( image7 );
    pixmapLabel6_2->setScaledContents( FALSE );
    layout10->addWidget( pixmapLabel6_2 );
    spacer11_2 = new QSpacerItem( 20, 18, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout10->addItem( spacer11_2 );
    layout15->addLayout( layout10 );

    upPiecePlaceHolder = new QLabel( this, "upPiecePlaceHolder" );
    upPiecePlaceHolder->setMinimumSize( QSize( 45, 31 ) );
    upPiecePlaceHolder->setMaximumSize( QSize( 45, 31 ) );
    upPiecePlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    upPiecePlaceHolder->setPixmap( image8 );
    upPiecePlaceHolder->setScaledContents( FALSE );
    layout15->addWidget( upPiecePlaceHolder );

    frame6 = new QFrame( this, "frame6" );
    frame6->setMinimumSize( QSize( 0, 31 ) );
    frame6->setMaximumSize( QSize( 32767, 31 ) );
    frame6->setPaletteBackgroundPixmap( image9 );
    frame6->setFrameShape( QFrame::NoFrame );
    frame6->setFrameShadow( QFrame::Plain );
    frame6->setLineWidth( 0 );
    frame6Layout = new QGridLayout( frame6, 1, 1, 0, 30, "frame6Layout"); 
    spacer12 = new QSpacerItem( 57, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame6Layout->addItem( spacer12, 0, 0 );

    layout25 = new QHBoxLayout( 0, 0, 8, "layout25"); 

    frame6Layout->addLayout( layout25, 0, 1 );
    layout15->addWidget( frame6 );

    pixmapLabel2 = new QLabel( this, "pixmapLabel2" );
    pixmapLabel2->setMinimumSize( QSize( 11, 31 ) );
    pixmapLabel2->setMaximumSize( QSize( 11, 31 ) );
    pixmapLabel2->setPixmap( image10 );
    pixmapLabel2->setScaledContents( FALSE );
    layout15->addWidget( pixmapLabel2 );
    spacer9_2_2 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout15->addItem( spacer9_2_2 );

    roomsLayout->addLayout( layout15, 3, 0 );

    layout79 = new QHBoxLayout( 0, 0, 0, "layout79"); 
    spacer99 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout79->addItem( spacer99 );

    frame48 = new QFrame( this, "frame48" );
    frame48->setMinimumSize( QSize( 100, 130 ) );
    frame48->setMaximumSize( QSize( 32767, 130 ) );
    frame48->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    frame48->setFrameShape( QFrame::Box );
    frame48->setFrameShadow( QFrame::Plain );
    frame48Layout = new QGridLayout( frame48, 1, 1, 9, 0, "frame48Layout"); 

    frame53 = new QFrame( frame48, "frame53" );
    frame53->setMinimumSize( QSize( 100, 105 ) );
    frame53->setMaximumSize( QSize( 32767, 105 ) );
    frame53->setFrameShape( QFrame::NoFrame );
    frame53->setFrameShadow( QFrame::Plain );
    frame53->setLineWidth( 0 );
    frame53Layout = new QGridLayout( frame53, 1, 1, 0, 0, "frame53Layout"); 

    layout111 = new QHBoxLayout( 0, 0, 0, "layout111"); 

    layout107 = new QVBoxLayout( 0, 0, 0, "layout107"); 

    roomlabel10_4_3_2 = new QLabel( frame53, "roomlabel10_4_3_2" );
    roomlabel10_4_3_2->setMinimumSize( QSize( 150, 20 ) );
    roomlabel10_4_3_2->setMaximumSize( QSize( 150, 20 ) );
    roomlabel10_4_3_2->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont roomlabel10_4_3_2_font(  roomlabel10_4_3_2->font() );
    roomlabel10_4_3_2_font.setBold( TRUE );
    roomlabel10_4_3_2->setFont( roomlabel10_4_3_2_font ); 
    layout107->addWidget( roomlabel10_4_3_2 );

    roomCategory = new QComboBox( FALSE, frame53, "roomCategory" );
    roomCategory->setMinimumSize( QSize( 100, 20 ) );
    roomCategory->setMaximumSize( QSize( 32767, 20 ) );
    roomCategory->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setDisabled( cg );
    roomCategory->setPalette( pal );
    roomCategory->setBackgroundOrigin( QComboBox::AncestorOrigin );
    roomCategory->setFocusPolicy( QComboBox::ClickFocus );
    layout107->addWidget( roomCategory );
    layout111->addLayout( layout107 );
    spacer131 = new QSpacerItem( 10, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout111->addItem( spacer131 );

    layout108 = new QVBoxLayout( 0, 0, 0, "layout108"); 
    spacer130 = new QSpacerItem( 20, 14, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout108->addItem( spacer130 );

    createPlaceHolder = new QLabel( frame53, "createPlaceHolder" );
    createPlaceHolder->setMinimumSize( QSize( 80, 28 ) );
    createPlaceHolder->setMaximumSize( QSize( 80, 28 ) );
    createPlaceHolder->setPixmap( image11 );
    createPlaceHolder->setScaledContents( FALSE );
    layout108->addWidget( createPlaceHolder );
    layout111->addLayout( layout108 );

    frame53Layout->addLayout( layout111, 5, 0 );

    layout106 = new QVBoxLayout( 0, 0, 0, "layout106"); 

    roomlabel10_4_3 = new QLabel( frame53, "roomlabel10_4_3" );
    roomlabel10_4_3->setMinimumSize( QSize( 150, 20 ) );
    roomlabel10_4_3->setMaximumSize( QSize( 150, 20 ) );
    roomlabel10_4_3->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont roomlabel10_4_3_font(  roomlabel10_4_3->font() );
    roomlabel10_4_3_font.setBold( TRUE );
    roomlabel10_4_3->setFont( roomlabel10_4_3_font ); 
    layout106->addWidget( roomlabel10_4_3 );

    roomPassword = new QLineEdit( frame53, "roomPassword" );
    roomPassword->setMinimumSize( QSize( 30, 20 ) );
    roomPassword->setMaximumSize( QSize( 32767, 20 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    roomPassword->setPalette( pal );
    layout106->addWidget( roomPassword );

    frame53Layout->addLayout( layout106, 3, 0 );

    layout105 = new QHBoxLayout( 0, 0, 0, "layout105"); 

    frame50_2_2 = new QFrame( frame53, "frame50_2_2" );
    frame50_2_2->setMinimumSize( QSize( 29, 25 ) );
    frame50_2_2->setMaximumSize( QSize( 32767, 25 ) );
    frame50_2_2->setPaletteBackgroundColor( QColor( 239, 243, 255 ) );
    frame50_2_2->setFrameShape( QFrame::Box );
    frame50_2_2->setFrameShadow( QFrame::Plain );
    frame50_2_2->setMargin( 0 );
    frame50_2_2Layout = new QGridLayout( frame50_2_2, 1, 1, 1, 11, "frame50_2_2Layout"); 

    privateSwitch = new QRadioButton( frame50_2_2, "privateSwitch" );
    privateSwitch->setMinimumSize( QSize( 90, 0 ) );
    privateSwitch->setFocusPolicy( QRadioButton::NoFocus );

    frame50_2_2Layout->addWidget( privateSwitch, 0, 3 );

    publicSwitch = new QRadioButton( frame50_2_2, "publicSwitch" );
    publicSwitch->setMinimumSize( QSize( 90, 0 ) );
    publicSwitch->setFocusPolicy( QRadioButton::NoFocus );

    frame50_2_2Layout->addWidget( publicSwitch, 0, 2 );
    spacer284 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame50_2_2Layout->addItem( spacer284, 0, 1 );

    searchLabel3_2 = new QLabel( frame50_2_2, "searchLabel3_2" );
    searchLabel3_2->setMinimumSize( QSize( 0, 16 ) );
    searchLabel3_2->setMaximumSize( QSize( 110, 110 ) );
    searchLabel3_2->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    searchLabel3_2->setPaletteBackgroundColor( QColor( 239, 243, 255 ) );
    searchLabel3_2->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont searchLabel3_2_font(  searchLabel3_2->font() );
    searchLabel3_2_font.setBold( TRUE );
    searchLabel3_2->setFont( searchLabel3_2_font ); 
    searchLabel3_2->setIndent( 7 );

    frame50_2_2Layout->addWidget( searchLabel3_2, 0, 0 );
    layout105->addWidget( frame50_2_2 );

    frame53Layout->addLayout( layout105, 1, 0 );

    frame48Layout->addWidget( frame53, 0, 2 );
    spacer98 = new QSpacerItem( 25, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame48Layout->addItem( spacer98, 0, 1 );

    frame52 = new QFrame( frame48, "frame52" );
    frame52->setMinimumSize( QSize( 100, 100 ) );
    frame52->setMaximumSize( QSize( 32767, 110 ) );
    frame52->setFrameShape( QFrame::NoFrame );
    frame52->setFrameShadow( QFrame::Plain );
    frame52Layout = new QGridLayout( frame52, 1, 1, 0, 0, "frame52Layout"); 

    roomlabel10_4 = new QLabel( frame52, "roomlabel10_4" );
    roomlabel10_4->setMinimumSize( QSize( 150, 20 ) );
    roomlabel10_4->setMaximumSize( QSize( 150, 20 ) );
    roomlabel10_4->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont roomlabel10_4_font(  roomlabel10_4->font() );
    roomlabel10_4_font.setBold( TRUE );
    roomlabel10_4->setFont( roomlabel10_4_font ); 

    frame52Layout->addWidget( roomlabel10_4, 0, 0 );

    createRoomName = new QLineEdit( frame52, "createRoomName" );
    createRoomName->setMinimumSize( QSize( 100, 20 ) );
    createRoomName->setMaximumSize( QSize( 32767, 20 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    createRoomName->setPalette( pal );
    createRoomName->setFocusPolicy( QLineEdit::StrongFocus );
    createRoomName->setFrameShape( QLineEdit::LineEditPanel );
    createRoomName->setFrameShadow( QLineEdit::Sunken );

    frame52Layout->addWidget( createRoomName, 1, 0 );

    roomAbout = new QTextEdit( frame52, "roomAbout" );
    roomAbout->setMinimumSize( QSize( 0, 0 ) );
    roomAbout->setMaximumSize( QSize( 32767, 44 ) );
    roomAbout->setVScrollBarMode( QTextEdit::Auto );
    roomAbout->setTextFormat( QTextEdit::PlainText );

    frame52Layout->addWidget( roomAbout, 3, 0 );

    roomlabel10_4_2 = new QLabel( frame52, "roomlabel10_4_2" );
    roomlabel10_4_2->setMinimumSize( QSize( 150, 20 ) );
    roomlabel10_4_2->setMaximumSize( QSize( 150, 20 ) );
    roomlabel10_4_2->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont roomlabel10_4_2_font(  roomlabel10_4_2->font() );
    roomlabel10_4_2_font.setBold( TRUE );
    roomlabel10_4_2->setFont( roomlabel10_4_2_font ); 

    frame52Layout->addWidget( roomlabel10_4_2, 2, 0 );

    frame48Layout->addWidget( frame52, 0, 0 );
    layout79->addWidget( frame48 );
    spacer100 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout79->addItem( spacer100 );

    roomsLayout->addLayout( layout79, 5, 0 );

    layout80 = new QVBoxLayout( 0, 0, 0, "layout80"); 
    spacer88 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout80->addItem( spacer88 );

    layout40_2 = new QHBoxLayout( 0, 0, 0, "layout40_2"); 
    spacer14_2_2 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout40_2->addItem( spacer14_2_2 );

    pixmapLabel4_2_2 = new QLabel( this, "pixmapLabel4_2_2" );
    pixmapLabel4_2_2->setMinimumSize( QSize( 0, 23 ) );
    pixmapLabel4_2_2->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel4_2_2->setPixmap( image12 );
    pixmapLabel4_2_2->setScaledContents( FALSE );
    layout40_2->addWidget( pixmapLabel4_2_2 );

    frame28_2 = new QFrame( this, "frame28_2" );
    frame28_2->setMinimumSize( QSize( 100, 23 ) );
    frame28_2->setMaximumSize( QSize( 32767, 23 ) );
    frame28_2->setPaletteBackgroundPixmap( image13 );
    frame28_2->setFrameShape( QFrame::NoFrame );
    frame28_2->setFrameShadow( QFrame::Plain );
    frame28_2Layout = new QGridLayout( frame28_2, 1, 1, 0, 0, "frame28_2Layout"); 

    roomCaption_2 = new QLabel( frame28_2, "roomCaption_2" );
    roomCaption_2->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    roomCaption_2->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont roomCaption_2_font(  roomCaption_2->font() );
    roomCaption_2_font.setBold( TRUE );
    roomCaption_2->setFont( roomCaption_2_font ); 

    frame28_2Layout->addWidget( roomCaption_2, 0, 0 );
    layout40_2->addWidget( frame28_2 );

    pixmapLabel4_3 = new QLabel( this, "pixmapLabel4_3" );
    pixmapLabel4_3->setMinimumSize( QSize( 0, 23 ) );
    pixmapLabel4_3->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel4_3->setPixmap( image14 );
    pixmapLabel4_3->setScaledContents( FALSE );
    layout40_2->addWidget( pixmapLabel4_3 );
    spacer15_2_2 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout40_2->addItem( spacer15_2_2 );
    layout80->addLayout( layout40_2 );

    roomsLayout->addLayout( layout80, 4, 0 );

    layout81 = new QVBoxLayout( 0, 0, 0, "layout81"); 

    layout156 = new QVBoxLayout( 0, 0, 0, "layout156"); 

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setMinimumSize( QSize( 100, 18 ) );
    textLabel1->setMaximumSize( QSize( 32767, 18 ) );
    textLabel1->setPaletteBackgroundPixmap( image15 );
    layout156->addWidget( textLabel1 );

    frame16 = new QFrame( this, "frame16" );
    frame16->setMinimumSize( QSize( 200, 21 ) );
    frame16->setMaximumSize( QSize( 32767, 21 ) );
    frame16->setPaletteBackgroundPixmap( image16 );
    frame16->setFrameShape( QFrame::NoFrame );
    frame16->setFrameShadow( QFrame::Plain );
    frame16Layout = new QGridLayout( frame16, 1, 1, 0, 0, "frame16Layout"); 

    pixmapLabel1 = new QLabel( frame16, "pixmapLabel1" );
    pixmapLabel1->setMinimumSize( QSize( 166, 21 ) );
    pixmapLabel1->setMaximumSize( QSize( 166, 21 ) );
    pixmapLabel1->setPixmap( image17 );
    pixmapLabel1->setScaledContents( FALSE );

    frame16Layout->addWidget( pixmapLabel1, 0, 0 );

    pixmapLabel2_2 = new QLabel( frame16, "pixmapLabel2_2" );
    pixmapLabel2_2->setMinimumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setMaximumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setPixmap( image18 );
    pixmapLabel2_2->setScaledContents( FALSE );

    frame16Layout->addWidget( pixmapLabel2_2, 0, 2 );
    spacer184 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame16Layout->addItem( spacer184, 0, 1 );
    layout156->addWidget( frame16 );
    layout81->addLayout( layout156 );
    spacer71 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout81->addItem( spacer71 );

    roomsLayout->addLayout( layout81, 0, 0 );

    layout40 = new QHBoxLayout( 0, 0, 0, "layout40"); 
    spacer14_2 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout40->addItem( spacer14_2 );

    pixmapLabel4_2 = new QLabel( this, "pixmapLabel4_2" );
    pixmapLabel4_2->setMinimumSize( QSize( 0, 23 ) );
    pixmapLabel4_2->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel4_2->setPixmap( image12 );
    pixmapLabel4_2->setScaledContents( FALSE );
    layout40->addWidget( pixmapLabel4_2 );

    frame28 = new QFrame( this, "frame28" );
    frame28->setMinimumSize( QSize( 100, 23 ) );
    frame28->setMaximumSize( QSize( 32767, 23 ) );
    frame28->setPaletteBackgroundPixmap( image13 );
    frame28->setFrameShape( QFrame::NoFrame );
    frame28->setFrameShadow( QFrame::Plain );
    frame28Layout = new QGridLayout( frame28, 1, 1, 0, 0, "frame28Layout"); 

    roomCaption = new QLabel( frame28, "roomCaption" );
    roomCaption->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    roomCaption->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont roomCaption_font(  roomCaption->font() );
    roomCaption_font.setBold( TRUE );
    roomCaption->setFont( roomCaption_font ); 

    frame28Layout->addWidget( roomCaption, 0, 0 );
    layout40->addWidget( frame28 );

    pixmapLabel4 = new QLabel( this, "pixmapLabel4" );
    pixmapLabel4->setMinimumSize( QSize( 0, 23 ) );
    pixmapLabel4->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel4->setPixmap( image14 );
    pixmapLabel4->setScaledContents( FALSE );
    layout40->addWidget( pixmapLabel4 );
    spacer15_2 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout40->addItem( spacer15_2 );

    roomsLayout->addLayout( layout40, 1, 0 );

    layout192 = new QHBoxLayout( 0, 0, 0, "layout192"); 
    spacer282 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout192->addItem( spacer282 );

    frame87 = new QFrame( this, "frame87" );
    frame87->setMinimumSize( QSize( 0, 0 ) );
    frame87->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    frame87->setFrameShape( QFrame::Box );
    frame87->setFrameShadow( QFrame::Plain );
    frame87Layout = new QGridLayout( frame87, 1, 1, 2, 0, "frame87Layout"); 
    spacer277 = new QSpacerItem( 25, 10, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame87Layout->addItem( spacer277, 0, 2 );
    spacer279 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame87Layout->addItem( spacer279, 0, 4 );

    layout83 = new QVBoxLayout( 0, 0, 0, "layout83"); 

    layout33 = new QVBoxLayout( 0, 3, 4, "layout33"); 

    roomlabel10_2 = new QLabel( frame87, "roomlabel10_2" );
    roomlabel10_2->setMinimumSize( QSize( 100, 20 ) );
    roomlabel10_2->setMaximumSize( QSize( 32767, 20 ) );
    roomlabel10_2->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont roomlabel10_2_font(  roomlabel10_2->font() );
    roomlabel10_2_font.setBold( TRUE );
    roomlabel10_2->setFont( roomlabel10_2_font ); 
    layout33->addWidget( roomlabel10_2 );

    frame50_2 = new QFrame( frame87, "frame50_2" );
    frame50_2->setMinimumSize( QSize( 100, 25 ) );
    frame50_2->setMaximumSize( QSize( 32767, 25 ) );
    frame50_2->setPaletteBackgroundColor( QColor( 239, 243, 255 ) );
    frame50_2->setFrameShape( QFrame::Box );
    frame50_2->setFrameShadow( QFrame::Plain );
    frame50_2Layout = new QGridLayout( frame50_2, 1, 1, 2, 0, "frame50_2Layout"); 

    searchLabel3 = new QLabel( frame50_2, "searchLabel3" );
    searchLabel3->setMinimumSize( QSize( 50, 0 ) );
    searchLabel3->setMaximumSize( QSize( 32767, 20 ) );
    searchLabel3->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    searchLabel3->setPaletteBackgroundColor( QColor( 239, 243, 255 ) );
    searchLabel3->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont searchLabel3_font(  searchLabel3->font() );
    searchLabel3_font.setBold( TRUE );
    searchLabel3->setFont( searchLabel3_font ); 
    searchLabel3->setIndent( 7 );

    frame50_2Layout->addWidget( searchLabel3, 0, 0 );

    systemSwitch = new QRadioButton( frame50_2, "systemSwitch" );
    systemSwitch->setMinimumSize( QSize( 90, 0 ) );
    systemSwitch->setMaximumSize( QSize( 90, 20 ) );
    systemSwitch->setFocusPolicy( QRadioButton::NoFocus );

    frame50_2Layout->addWidget( systemSwitch, 0, 2 );

    userSwitch = new QRadioButton( frame50_2, "userSwitch" );
    userSwitch->setMinimumSize( QSize( 90, 0 ) );
    userSwitch->setMaximumSize( QSize( 90, 20 ) );
    userSwitch->setFocusPolicy( QRadioButton::NoFocus );

    frame50_2Layout->addWidget( userSwitch, 0, 3 );
    spacer37 = new QSpacerItem( 40, 16, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame50_2Layout->addItem( spacer37, 0, 1 );
    layout33->addWidget( frame50_2 );

    roomList = new QListView( frame87, "roomList" );
    roomList->setMinimumSize( QSize( 0, 30 ) );
    roomList->setFocusPolicy( QListView::ClickFocus );
    roomList->setFrameShape( QListView::Box );
    roomList->setFrameShadow( QListView::Plain );
    roomList->setLineWidth( 1 );
    roomList->setResizePolicy( QListView::AutoOneFit );
    roomList->setHScrollBarMode( QListView::AlwaysOff );
    roomList->setAllColumnsShowFocus( TRUE );
    roomList->setRootIsDecorated( TRUE );
    roomList->setResizeMode( QListView::AllColumns );
    layout33->addWidget( roomList );
    layout83->addLayout( layout33 );

    layout81_2 = new QHBoxLayout( 0, 0, 0, "layout81_2"); 

    layout75 = new QVBoxLayout( 0, 0, 0, "layout75"); 

    roomlabel10_3 = new QLabel( frame87, "roomlabel10_3" );
    roomlabel10_3->setMinimumSize( QSize( 100, 20 ) );
    roomlabel10_3->setMaximumSize( QSize( 150, 20 ) );
    roomlabel10_3->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont roomlabel10_3_font(  roomlabel10_3->font() );
    roomlabel10_3_font.setBold( TRUE );
    roomlabel10_3->setFont( roomlabel10_3_font ); 
    roomlabel10_3->setIndent( -1 );
    layout75->addWidget( roomlabel10_3 );

    roomName = new QLineEdit( frame87, "roomName" );
    roomName->setMinimumSize( QSize( 156, 20 ) );
    roomName->setMaximumSize( QSize( 32767, 20 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    roomName->setPalette( pal );
    roomName->setFocusPolicy( QLineEdit::StrongFocus );
    layout75->addWidget( roomName );
    layout81_2->addLayout( layout75 );
    spacer79 = new QSpacerItem( 8, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout81_2->addItem( spacer79 );

    layout80_2 = new QVBoxLayout( 0, 0, 0, "layout80_2"); 
    spacer133_2 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout80_2->addItem( spacer133_2 );

    layout79_2 = new QHBoxLayout( 0, 0, 0, "layout79_2"); 

    enterRoomPlaceHolder = new QLabel( frame87, "enterRoomPlaceHolder" );
    enterRoomPlaceHolder->setMinimumSize( QSize( 80, 28 ) );
    enterRoomPlaceHolder->setMaximumSize( QSize( 80, 28 ) );
    enterRoomPlaceHolder->setPixmap( image19 );
    enterRoomPlaceHolder->setScaledContents( FALSE );
    layout79_2->addWidget( enterRoomPlaceHolder );
    spacer78 = new QSpacerItem( 6, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout79_2->addItem( spacer78 );

    searchRoomPlaceHolder = new QLabel( frame87, "searchRoomPlaceHolder" );
    searchRoomPlaceHolder->setMinimumSize( QSize( 83, 28 ) );
    searchRoomPlaceHolder->setMaximumSize( QSize( 83, 28 ) );
    searchRoomPlaceHolder->setPixmap( image19 );
    searchRoomPlaceHolder->setScaledContents( FALSE );
    layout79_2->addWidget( searchRoomPlaceHolder );
    layout80_2->addLayout( layout79_2 );
    layout81_2->addLayout( layout80_2 );
    layout83->addLayout( layout81_2 );
    spacer281 = new QSpacerItem( 20, 14, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout83->addItem( spacer281 );

    frame87Layout->addLayout( layout83, 0, 3 );
    spacer38 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame87Layout->addItem( spacer38, 0, 0 );

    layout27 = new QVBoxLayout( 0, 0, 0, "layout27"); 

    layout26 = new QVBoxLayout( 0, 0, 0, "layout26"); 

    roomlabel10 = new QLabel( frame87, "roomlabel10" );
    roomlabel10->setMinimumSize( QSize( 100, 26 ) );
    roomlabel10->setMaximumSize( QSize( 32767, 26 ) );
    roomlabel10->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont roomlabel10_font(  roomlabel10->font() );
    roomlabel10_font.setBold( TRUE );
    roomlabel10->setFont( roomlabel10_font ); 
    layout26->addWidget( roomlabel10 );

    categoryList = new QListView( frame87, "categoryList" );
    categoryList->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, 0, 0, categoryList->sizePolicy().hasHeightForWidth() ) );
    categoryList->setMinimumSize( QSize( 100, 0 ) );
    categoryList->setFocusPolicy( QListView::ClickFocus );
    categoryList->setFrameShape( QListView::Box );
    categoryList->setFrameShadow( QListView::Plain );
    categoryList->setLineWidth( 1 );
    categoryList->setResizePolicy( QListView::AutoOneFit );
    categoryList->setHScrollBarMode( QListView::Auto );
    categoryList->setAllColumnsShowFocus( TRUE );
    categoryList->setRootIsDecorated( TRUE );
    categoryList->setResizeMode( QListView::AllColumns );
    layout26->addWidget( categoryList );
    spacer280 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout26->addItem( spacer280 );
    layout27->addLayout( layout26 );

    frame87Layout->addLayout( layout27, 0, 1 );
    layout192->addWidget( frame87 );
    spacer283 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout192->addItem( spacer283 );

    roomsLayout->addLayout( layout192, 2, 0 );
    languageChange();
    resize( QSize(608, 535).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // tab order
    setTabOrder( roomName, createRoomName );
    setTabOrder( createRoomName, roomPassword );
    setTabOrder( roomPassword, roomCategory );
    setTabOrder( roomCategory, roomAbout );
    setTabOrder( roomAbout, categoryList );
    setTabOrder( categoryList, roomList );
    setTabOrder( roomList, systemSwitch );
    setTabOrder( systemSwitch, publicSwitch );
    setTabOrder( publicSwitch, privateSwitch );
    setTabOrder( privateSwitch, userSwitch );
}

/*
 *  Destroys the object and frees any allocated resources
 */
rooms::~rooms()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void rooms::languageChange()
{
    setCaption( ( "Gestione stanze" ) );
    roomlabel10_4_3_2->setText( ( "Categoria" ) );
    roomlabel10_4_3->setText( ( "Password" ) );
    privateSwitch->setText( ( "privata" ) );
    publicSwitch->setText( ( "pubblica" ) );
    searchLabel3_2->setText( ( "Crea come:" ) );
    roomlabel10_4->setText( ( "Nome stanza" ) );
    roomlabel10_4_2->setText( ( "Si parla di" ) );
    roomCaption_2->setText( ( "Crea stanza" ) );
    roomCaption->setText( ( "Cerca o entra in stanza" ) );
    roomlabel10_2->setText( ( "Risultati della ricerca" ) );
    searchLabel3->setText( ( "Filtra" ) );
    systemSwitch->setText( ( "sistema" ) );
    userSwitch->setText( ( "utenti" ) );
    roomlabel10_3->setText( ( "Nome stanza" ) );
    roomlabel10->setText( ( "Categorie" ) );
}

#include "rooms.moc"
